@@ -1,6 +1,6 @@
 /* FormantPathEditor.cpp
  *
- * Copyright (C) 2020-2021 David Weenink, 2022 Paul Boersma
+ * Copyright (C) 2020-2022 David Weenink, 2022 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,15 @@
 	TODO: make width of selection viewer variable?
 */
 #include "FormantPathEditor.h"
+#include "Graphics_extensions.h"
 #include "EditorM.h"
+#include "Formant_extensions.h"
+#include "LPC_and_Formant.h"
+#include "NUM2.h"
+#include "PitchTier.h"
+#include "PitchTier_to_PointProcess.h"
+#include "Sound_and_LPC.h"
+#include "Sound_extensions.h"
 
 Thing_implement (FormantPathEditor, FunctionEditor, 0);
 
@@ -30,6 +38,7 @@ Thing_implement (FormantPathEditor, FunctionEditor, 0);
 #include "FormantPathEditor_prefs.h"
 #include "Prefs_copyToInstance.h"
 #include "FormantPathEditor_prefs.h"
+#include "PointProcess_and_Sound.h"
 
 void structFormantPathEditor :: v1_info () {
 	FormantPathEditor_Parent :: v1_info ();
@@ -44,6 +53,79 @@ MelderColour markedCandidatesColour =  MelderColour (0.984,0.984, 0.7);
 
 /********** UTILITIES **********/
 
+#define MAX_T  0.02000000001   /* Maximum interval between two voice pulses (otherwise voiceless). */
+
+static autoPitchTier Pitch_to_PitchTier_part (Pitch me, double startTime, double endTime) {
+	try {
+		autoPitchTier thee = PitchTier_create (startTime, endTime);
+		for (integer i = 1; i <= my nx; i ++) {
+			const double time = Sampled_indexToX (me, i);
+			if (time < startTime)
+				continue;
+			if (time > endTime)
+				break;
+			const double frequency = my frames [i]. candidates [1]. frequency;
+			/*
+				Count only voiced frames.
+			*/
+			if (Pitch_util_frequencyIsVoiced (frequency, my ceiling)) {
+				RealTier_addPoint (thee.get(), time, frequency);
+			}
+		}
+		return thee;
+	} catch (MelderError) {
+		Melder_throw (me, U": part not converted to PitchTier.");
+	}
+}
+
+static autoPointProcess PointProcess_extractPart (PointProcess me, double startTime, double endTime) {
+	try {
+		integer i1 = 1, i2 = my nt;
+		while (i1 <= my nt && my t [i1] < startTime)
+			i1 ++;
+		while (i2 >= 1 && my t [i2] > endTime)
+			i2 --;
+		const integer nt = i2 - i1 + 1;
+		Melder_require (nt > 0,
+			U"There must be at least one point in the interval.");
+		autoPointProcess thee = PointProcess_create (startTime, endTime, nt);
+		thy nt = nt;
+		thy t.size = nt;
+		thy t.get()  <<= my t.part (i1, i2);
+		return thee;
+	} catch (MelderError) {
+			Melder_throw (me, U": could not extract part.");
+	}
+}
+
+static autoSound FormantPathEditor_getResynthesis (FormantPathEditor me, double startTime, double endTime) {
+	try {
+		SoundAnalysisArea_haveVisiblePitch (my formantPathArea().get());
+		Pitch pitch = my formantPathArea() -> d_pitch.get();
+		autoPitchTier pitchtierPart = Pitch_to_PitchTier_part (pitch, startTime, endTime);
+		
+		SoundAnalysisArea_haveVisiblePulses (my formantPathArea().get());
+		PointProcess pulses = my formantPathArea() -> d_pulses.get();
+		autoPointProcess pulsesPart = PointProcess_extractPart (pulses, startTime, endTime);
+		
+		autoPointProcess pulses2 = PitchTier_Point_to_PointProcess (pitchtierPart.get(), pulsesPart.get(), MAX_T);
+		const double samplingFrequency = 22050.0;
+		autoSound train = PointProcess_to_Sound_pulseTrain (pulses2.get(), samplingFrequency , 0.7, 0.05, 30);
+		
+		autoFormant formantPart = Formant_extractPart (my formantPathArea() -> d_formant.get(), startTime, endTime);
+		autoLPC lpc = Formant_to_LPC (formantPart.get(), 1.0 / samplingFrequency);
+		
+		autoSound sound = LPC_Sound_filter (lpc.get(), train.get(), false);
+		Vector_scale (sound.get(), 0.99);
+		constexpr double fadeTime = 0.005;
+		Sound_fade (sound.get(), 0, sound -> xmin, fadeTime, false, true);
+		Sound_fade (sound.get(), 0, sound -> xmax, -fadeTime, true, true);
+		return sound;
+	} catch (MelderError) {
+		Melder_throw (U"Could not synthesize.");
+	}
+}
+
 static void FormantPathEditor_getDrawingData (FormantPathEditor me, double *out_startTime, double *out_endTime, double *out_xCursor, double *out_yCursor) {
 	double startTime = my startWindow, endTime = my endWindow;
 	double xCursor;
@@ -67,11 +149,30 @@ static void FormantPathEditor_getDrawingData (FormantPathEditor me, double *out_
 				my formantPathArea() -> d_spectrogram_cursor < my formantPathArea() -> instancePref_spectrogram_viewTo() ? my formantPathArea() -> d_spectrogram_cursor : -1000.0 );
 }
 
+static void Formant_replaceFrames (Formant target, integer beginFrame, integer endFrame, Formant source) {
+	// Precondition target and source have exactly the same Sampled xmin, xmax, x1, nx, dx
+	if (beginFrame == endFrame && beginFrame == 0) {
+		beginFrame = 1;
+		endFrame = target -> nx;
+	}
+	Melder_require (beginFrame <= endFrame,
+		U"The start frame should not be after the end frame.");
+	Melder_require (beginFrame > 0, 
+		U"The begin frame should be larger than zero.");
+	Melder_require (endFrame <= target->nx,
+		U"The end frame sould not be larger than ", target->nx);
+	for (integer iframe = beginFrame ; iframe <= endFrame; iframe ++) {
+		Formant_Frame targetFrame = & target -> frames [iframe];
+		Formant_Frame sourceFrame = & source -> frames [iframe];
+		sourceFrame -> copy (targetFrame);
+	}
+}
+
 /********** METHODS **********/
 
 /***** TIER MENU *****/
 
-static void menu_cb_candidate_modellingSettings (FormantPathEditor me, EDITOR_ARGS_FORM) {
+static void menu_cb_candidate_modellingSettings (FormantPathEditor me, EDITOR_ARGS) {
 	EDITOR_FORM (U"Candidate modelling settings", U"Candidate modelling settings...")		
 		SENTENCE (parameters_string, U"Coefficients by track", my default_modeler_numberOfParametersPerTrack())
 		POSITIVE (varianceExponent, U"Variance exponent", U"1.25")
@@ -82,6 +183,9 @@ static void menu_cb_candidate_modellingSettings (FormantPathEditor me, EDITOR_AR
 	autoINTVEC parameters = splitByWhitespaceWithRanges_INTVEC (my instancePref_modeler_numberOfParametersPerTrack());
 	Melder_require (parameters.size > 0,
 		U"At least one coefficient should be given.");
+	const integer numberOfTracks = FormantPath_getNumberOfFormantTracks (my formantPath());
+	Melder_require (parameters.size <= numberOfTracks,
+		U"The number of coefficients (", parameters.size, U") should not exceed the number of tracks (", numberOfTracks, U").");
 	Melder_require (NUMmin (parameters.get()) > 0,
 		U"All coefficients should be larger than zero.");
 	my setInstancePref_modeler_varianceExponent (varianceExponent);
@@ -89,7 +193,7 @@ static void menu_cb_candidate_modellingSettings (FormantPathEditor me, EDITOR_AR
 	EDITOR_END
 }
 
-static void menu_cb_AdvancedCandidateDrawingSettings (FormantPathEditor me, EDITOR_ARGS_FORM) {
+static void menu_cb_AdvancedCandidateDrawingSettings (FormantPathEditor me, EDITOR_ARGS) {
 	EDITOR_FORM (U"Formant modeler advanced drawing settings", nullptr)
 		BOOLEAN (drawEstimatedModels, U"Draw estimated models", my default_modeler_draw_estimatedModels())
 		POSITIVE (yGridLineEvery_Hz, U"Hor. grid lines every (Hz)", my default_modeler_draw_yGridLineEvery_Hz())
@@ -109,7 +213,7 @@ static void menu_cb_AdvancedCandidateDrawingSettings (FormantPathEditor me, EDIT
 	EDITOR_END
 }
 
-static void menu_cb_candidates_FindPath (FormantPathEditor me, EDITOR_ARGS_FORM) {
+static void menu_cb_candidates_FindPath (FormantPathEditor me, EDITOR_ARGS) {
 	EDITOR_FORM (U"Find path", nullptr)
 		LABEL (U"Within frame:")
 		REAL (qWeight, U"F/B weight (0-1)", U"1.0")
@@ -131,7 +235,29 @@ static void menu_cb_candidates_FindPath (FormantPathEditor me, EDITOR_ARGS_FORM)
 	EDITOR_END
 }
 
-static void menu_cb_DrawVisibleCandidates (FormantPathEditor me, EDITOR_ARGS_FORM) {
+static void menu_cb_selectCandidateWithlowestStress (FormantPathEditor me, EDITOR_ARGS) {
+	double startTime = my startSelection, endTime = my endSelection;
+	if (my startSelection == my endSelection) {
+		startTime = my startWindow;
+		endTime = my endWindow;
+	}
+	autoINTVEC parameters = splitByWhitespaceWithRanges_INTVEC (my instancePref_modeler_numberOfParametersPerTrack());
+	autoVEC stresses = FormantPath_getStressOfCandidates (my formantPath(), startTime, endTime, 0, 0, parameters.get(), 
+		my instancePref_modeler_varianceExponent());
+	const integer minPos = NUMminPos (stresses.get());
+	my selectedCandidate = minPos;
+	Editor_save (me, U"Change ceiling");
+	integer ifmin, ifmax;
+	Sampled_getWindowSamples (my formantPath(), startTime, endTime, & ifmin, & ifmax);
+	for (integer iframe = ifmin; iframe <= ifmax; iframe ++)
+		my formantPath() -> path [iframe] = my selectedCandidate;
+	Formant source = my formantPath() -> formantCandidates.at [my selectedCandidate];
+	Formant_replaceFrames (my formantPathArea() -> d_formant.get(), ifmin, ifmax, source);
+	FunctionEditor_redraw (me);
+	Editor_broadcastDataChanged (me);
+}
+
+static void menu_cb_DrawVisibleCandidates (FormantPathEditor me, EDITOR_ARGS) {
 	EDITOR_FORM (U"Draw visible candidates", nullptr)
 		my v_form_pictureWindow (cmd);
 		my v_form_pictureMargins (cmd);
@@ -145,25 +271,44 @@ static void menu_cb_DrawVisibleCandidates (FormantPathEditor me, EDITOR_ARGS_FOR
 		my v_do_pictureWindow (cmd);
 		my v_do_pictureMargins (cmd);
 		my formantPathArea() -> setClassPref_picture_garnish (garnish);
-		Editor_openPraatPicture (me);
-		Graphics_setInner (my pictureGraphics);
+		DataGui_openPraatPicture (me);
+		Graphics_setInner (my pictureGraphics());
 		double startTime, endTime, xCursor, yCursor;
 		FormantPathEditor_getDrawingData (me, & startTime, & endTime, & xCursor, & yCursor);
 		autoINTVEC parameters = splitByWhitespaceWithRanges_INTVEC (my instancePref_modeler_numberOfParametersPerTrack());
 		constexpr double xSpace_fraction = 0.1, ySpace_fraction = 0.2;
-		FormantPath_drawAsGrid_inside (my formantPath(), my pictureGraphics, startTime, endTime,
+		FormantPath_drawAsGrid_inside (my formantPath(), my pictureGraphics(), startTime, endTime,
 			my instancePref_modeler_draw_maximumFrequency(), 1, 5,
 			my instancePref_modeler_draw_showBandwidths(), Melder_RED, Melder_PURPLE, 0, 0,
 			xSpace_fraction, ySpace_fraction, my instancePref_modeler_draw_yGridLineEvery_Hz(),
 			xCursor, yCursor, markedCandidatesColour, parameters.get(), true, true,
 			my instancePref_modeler_varianceExponent(), my instancePref_modeler_draw_estimatedModels(), true
 		);
-		Graphics_unsetInner (my pictureGraphics);
-		Editor_closePraatPicture (me);
+		Graphics_unsetInner (my pictureGraphics());
+		DataGui_closePraatPicture (me);
 	EDITOR_END
 }
 
-static void INFO_DATA__stressOfFitsListing (FormantPathEditor me, EDITOR_ARGS_DIRECT_WITH_OUTPUT) {
+static void menu_cb_play_resynthesis (FormantPathEditor me, EDITOR_ARGS) {
+	PLAY_DATA
+		MelderAudio_stopPlaying (MelderAudio_IMPLICIT);
+		double startTime,endTime;
+		FormantPathEditor_getDrawingData (me, & startTime, & endTime, nullptr, nullptr);
+		autoSound resynthesis = FormantPathEditor_getResynthesis (me, startTime, endTime);
+		Sound_playPart (resynthesis.get(), startTime, endTime, theFunctionEditor_playCallback, me);
+	PLAY_DATA_END
+}
+
+static void menu_cb_extract_resynthesis (FormantPathEditor me, EDITOR_ARGS) {
+	CONVERT_DATA_TO_ONE
+		double startTime,endTime;
+		FormantPathEditor_getDrawingData (me, & startTime, & endTime, nullptr, nullptr);
+	
+		autoSound result = FormantPathEditor_getResynthesis (me, startTime, endTime);
+	CONVERT_DATA_TO_ONE_END (U"untitled")
+}
+
+static void INFO_DATA__stressOfFitsListing (FormantPathEditor me, EDITOR_ARGS) {
 	INFO_DATA
 		double startTime = my startSelection, endTime = my endSelection;
 		if (my startSelection == my endSelection) {
@@ -180,21 +325,28 @@ static void INFO_DATA__stressOfFitsListing (FormantPathEditor me, EDITOR_ARGS_DI
 
 /***** HELP MENU *****/
 
-static void menu_cb_FormantPathEditorHelp (FormantPathEditor, EDITOR_ARGS_DIRECT) { Melder_help (U"FormantPathEditor"); }
-static void menu_cb_AboutSpecialSymbols (FormantPathEditor, EDITOR_ARGS_DIRECT) { Melder_help (U"Special symbols"); }
-static void menu_cb_PhoneticSymbols (FormantPathEditor, EDITOR_ARGS_DIRECT) { Melder_help (U"Phonetic symbols"); }
-static void menu_cb_AboutTextStyles (FormantPathEditor, EDITOR_ARGS_DIRECT) { Melder_help (U"Text styles"); }
+static void menu_cb_FormantPathEditorHelp (FormantPathEditor, EDITOR_ARGS) { Melder_help (U"FormantPathEditor"); }
+static void menu_cb_AboutSpecialSymbols (FormantPathEditor, EDITOR_ARGS) { Melder_help (U"Special symbols"); }
+static void menu_cb_PhoneticSymbols (FormantPathEditor, EDITOR_ARGS) { Melder_help (U"Phonetic symbols"); }
+static void menu_cb_AboutTextStyles (FormantPathEditor, EDITOR_ARGS) { Melder_help (U"Text styles"); }
 
 void structFormantPathEditor :: v_createMenus () {
 	FormantPathEditor_Parent :: v_createMenus ();
 	EditorMenu menu = Editor_addMenu (this, U"Candidates", 0);
 	EditorMenu_addCommand (menu, U"Candidate modelling settings...", 0, menu_cb_candidate_modellingSettings);
 	EditorMenu_addCommand (menu, U"Advanced candidate drawing settings...", 0, menu_cb_AdvancedCandidateDrawingSettings);
-	EditorMenu_addCommand (menu, U" -- drawing -- ", 0, 0);
-	EditorMenu_addCommand (menu, U"Find path...", 0, menu_cb_candidates_FindPath);
-	EditorMenu_addCommand (menu, U"Draw visible candidates...", 0, menu_cb_DrawVisibleCandidates);
-	EditorMenu_addCommand (menu, U" -- candidate queries -- ", 0, 0);
+	EditorMenu_addCommand (menu, U"- Draw candidates to picture window:", 0, nullptr);
+		EditorMenu_addCommand (menu, U"Draw visible candidates...", 1, menu_cb_DrawVisibleCandidates);
+	EditorMenu_addCommand (menu, U"- Select candidates:", 0, nullptr);
+		EditorMenu_addCommand (menu, U"Select candidate with lowest stress", 1, menu_cb_selectCandidateWithlowestStress);
+	EditorMenu_addCommand (menu, U"Find path...", 1, menu_cb_candidates_FindPath);
+	EditorMenu_addCommand (menu, U"-- candidate queries --", 0, 0);
 	EditorMenu_addCommand (menu, U"Stress of fits listing", 0, INFO_DATA__stressOfFitsListing);
+	if (soundArea()) {
+		EditorMenu_addCommand (menu, U"- Candidate resynthesis:", 0, nullptr);
+		EditorMenu_addCommand (menu, U"Play resynthesis", 1, menu_cb_play_resynthesis);
+		EditorMenu_addCommand (menu, U"Extract resynthesis", 1, menu_cb_extract_resynthesis);
+	}
 }
 
 void structFormantPathEditor :: v_createMenuItems_help (EditorMenu menu) {
@@ -217,13 +369,24 @@ void structFormantPathEditor :: v_drawSelectionViewer () {
 	Graphics_setTextAlignment (our graphics.get(), Graphics_CENTRE, Graphics_HALF);
 	double startTime, endTime = endWindow, xCursor, yCursor;
 	FormantPathEditor_getDrawingData (this, & startTime, & endTime, & xCursor, & yCursor);
-	Graphics_setInner (our graphics.get());
 	const integer nrow = 0, ncol = 0;
 	if (startTime != previousStartTime || endTime != previousEndTime)
 		our selectedCandidate = 0;
 	autoINTVEC parameters = splitByWhitespaceWithRanges_INTVEC (our instancePref_modeler_numberOfParametersPerTrack());
 	MelderColour oddColour = MelderColour_fromColourName (our formantPathArea() -> instancePref_formant_path_oddColour());
 	MelderColour evenColour = MelderColour_fromColourName (our formantPathArea() -> instancePref_formant_path_evenColour());
+	/*
+		Put the number of model coefficients per track at the top
+	*/
+	Graphics_setWindow (our graphics.get(), 0.0, 1.0, 0.0, 1.0);
+	autoMelderString infoAtTop;
+	MelderString_append (& infoAtTop, U"Coefficients by track: ", our instancePref_modeler_numberOfParametersPerTrack());
+	Graphics_setTextAlignment (our graphics.get(), Graphics_CENTRE, Graphics_BOTTOM);
+	Graphics_text (our graphics.get(), 0.5, 1.0, infoAtTop.string);
+	/*
+		Now do the inset
+	*/
+	Graphics_setInner (our graphics.get());
 	FormantPath_drawAsGrid_inside (our formantPath(), our graphics.get(), startTime, endTime,
 		our instancePref_modeler_draw_maximumFrequency(), 1, 5, our instancePref_modeler_draw_showBandwidths(), oddColour, evenColour,
 		nrow, ncol, xSpace_fraction, ySpace_fraction, our instancePref_modeler_draw_yGridLineEvery_Hz(), xCursor, yCursor, markedCandidatesColour,
@@ -234,60 +397,43 @@ void structFormantPathEditor :: v_drawSelectionViewer () {
 	previousEndTime = endTime;
 }
 
-static void Formant_replaceFrames (Formant target, integer beginFrame, integer endFrame, Formant source) {
-	// Precondition target and source have exactly the same Sampled xmin, xmax, x1, nx, dx
-	if (beginFrame == endFrame && beginFrame == 0) {
-		beginFrame = 1;
-		endFrame = target -> nx;
-	}
-	Melder_require (beginFrame <= endFrame,
-		U"The start frame should not be after the end frame.");
-	Melder_require (beginFrame > 0, 
-		U"The begin frame should be larger than zero.");
-	Melder_require (endFrame <= target->nx,
-		U"The end frame sould not be larger than ", target->nx);
-	for (integer iframe = beginFrame ; iframe <= endFrame; iframe ++) {
-		Formant_Frame targetFrame = & target -> frames [iframe];
-		Formant_Frame sourceFrame = & source -> frames [iframe];
-		sourceFrame -> copy (targetFrame);
-	}
-}
-
 void structFormantPathEditor :: v_clickSelectionViewer (double xWC, double yWC) {
 	/*
 		On which of the modelers was the click?
 	*/
-	integer numberOfRows, numberOfColums;
-	FormantPath_getGridDimensions (our formantPath(), & numberOfRows, & numberOfColums);
-	const integer icol = 1 + (int) (xWC * numberOfColums);
-	if (icol < 1 || icol > numberOfColums)
-		return;
-	const integer irow = 1 + (int) ((1.0 - yWC) * numberOfRows);
-	if (irow < 1 || irow > numberOfRows)
-		return;
-	integer index = (irow - 1) * numberOfColums + icol; // left-to-right, top-to-bottom
-	if (index > 0 && index <= our formantPath() -> formants.size) {
+	integer numberOfRows, numberOfColumns;
+	const integer numberOfCandidates = our formantPath() -> formantCandidates.size;
+	getGridLayout (numberOfCandidates, & numberOfRows, & numberOfColumns);
+	integer candidate = getGridCellIndex (xWC, yWC, numberOfRows, numberOfColumns);
+	if (candidate > 0 && candidate <= our formantPath() -> formantCandidates.size) {
 		double tmin_ = our startWindow, tmax_ = our endWindow;
 		if (our startSelection < our endSelection) {
 			tmin_ = our startSelection;
 			tmax_ = our endSelection;
 		}
-		our selectedCandidate = index;
+		our selectedCandidate = candidate;
 		Editor_save (this, U"Change ceiling");
-		integer itmin, itmax;
-		Sampled_getWindowSamples (our formantPath(), tmin_, tmax_, & itmin, & itmax);
-		for (integer iframe = itmin; iframe <= itmax; iframe ++)
+		integer ifmin, ifmax;
+		Sampled_getWindowSamples (our formantPath(), tmin_, tmax_, & ifmin, & ifmax);
+		for (integer iframe = ifmin; iframe <= ifmax; iframe ++)
 			our formantPath() -> path [iframe] = our selectedCandidate;
-		Formant source = our formantPath() -> formants.at [our selectedCandidate];
-		Formant_replaceFrames (our formantPathArea() -> d_formant.get(), itmin, itmax, source);
+		Formant source = our formantPath() -> formantCandidates.at [our selectedCandidate];
+		Formant_replaceFrames (our formantPathArea() -> d_formant.get(), ifmin, ifmax, source);
 	}
 	FunctionEditor_redraw (this);
 	Editor_broadcastDataChanged (this);
 }
 
 void structFormantPathEditor :: v_play (double startingTime, double endTime) {
-	if (our soundArea())
-		SoundArea_play (our soundArea().get(), startingTime, endTime);
+	if (our soundArea()) {
+		if (our clickWasModifiedByShiftKey) {
+			autoSound resynthesis = FormantPathEditor_getResynthesis (this, startingTime, endTime);
+			Sound_playPart (resynthesis.get(), startingTime, endTime, theFunctionEditor_playCallback, this);
+			our clickWasModifiedByShiftKey = false;
+		} else {
+			SoundArea_play (our soundArea().get(), startingTime, endTime);
+		}
+	}
 }
 
 /********** EXPORTED **********/
@@ -295,7 +441,8 @@ void structFormantPathEditor :: v_play (double startingTime, double endTime) {
 autoFormantPathEditor FormantPathEditor_create (conststring32 title, FormantPath formantPath, Sound soundToCopy, TextGrid textGridToCopy) {
 	try {
 		autoFormantPathEditor me = Thing_new (FormantPathEditor);
-		my soundArea() = SoundArea_create (false, soundToCopy, me.get());
+		if (soundToCopy)
+			my soundArea() = SoundArea_create (false, soundToCopy, me.get());
 		my formantPathArea() = FormantPathArea_create (true, soundToCopy, me.get());
 		my formantPathArea() -> _formantPath = formantPath;
 		if (textGridToCopy)
