@@ -1,6 +1,6 @@
 /* FormantPath_def.h
  *
- * Copyright (C) 2020 David Weenink
+ * Copyright (C) 2020, 2022 David Weenink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,18 +19,18 @@
 #define ooSTRUCT FormantPath
 oo_DEFINE_CLASS (FormantPath, Sampled)
 
-	oo_COLLECTION_OF (OrderedOf, formants, Formant, 2)
-	oo_VEC (ceilings, formants. size)
+	oo_COLLECTION_OF (OrderedOf, formantCandidates, Formant, 2)
+	oo_VEC (ceilings, formantCandidates. size)
 	oo_INTVEC (path, nx)
 	
 	#if oo_DECLARING
 		void v1_info ()
 			override;
-		int v_domainQuantity ()
+		int v_domainQuantity () const
 			override { return MelderQuantity_TIME_SECONDS; }
-		conststring32 v_getUnitText (integer level, int unit, uint32 flags)
+		conststring32 v_getUnitText (integer level, int unit, uint32 flags) const
 			override;
-		double v_getValueAtSample (integer sampleNumber, integer level, int unit)
+		double v_getValueAtSample (integer sampleNumber, integer level, int unit) const
 			override;
 		conststring32 v_getIndexText () const
 			override { return U"frame number"; }
