@@ -189,6 +189,66 @@ DIRECT (QUERY_ONE_FOR_REAL_VECTOR__FormantPath_listCeilingFrequencies) {
 	QUERY_ONE_FOR_REAL_VECTOR_END
 }
 
+FORM (QUERY_ONE_FOR_REAL__FormantPath_getOptimalCeiling, U"FormantPath: Get optimal ceiling", U"") {
+	REAL (tmin, U"left Time range (s)", U"0.0")
+	REAL (tmax, U"right Time range (s)", U"0.0 (=all)")
+	NATURALVECTOR (parameters, U"Coefficients by track", WHITESPACE_SEPARATED_, U"3 3 3")
+	POSITIVE (powerf, U"Power", U"1.25")
+	OK
+DO
+	QUERY_ONE_FOR_REAL (FormantPath)
+		double result = FormantPath_getOptimalCeiling (me, tmin, tmax, parameters, powerf);
+	QUERY_ONE_FOR_REAL_END (U"")
+}
+
+FORM (QUERY_ONE_FOR_REAL__FormantPath_getStressOfCandidate, U"FormantPath: Get stress of candidate", U"") {
+	REAL (tmin, U"left Time range (s)", U"0.0")
+	REAL (tmax, U"right Time range (s)", U"0.0 (=all)")
+	NATURAL (candidate, U"Candidate number", U"5")
+	NATURALVECTOR (parameters, U"Coefficients by track", WHITESPACE_SEPARATED_, U"3 3 3")
+	POSITIVE (powerf, U"Power", U"1.25")
+	OK
+DO
+	QUERY_ONE_FOR_REAL (FormantPath)
+		double result = FormantPath_getStressOfCandidate (me, tmin, tmax, 0, 0, parameters, powerf, candidate);
+	QUERY_ONE_FOR_REAL_END (U"")
+}
+
+FORM (QUERY_ONE_FOR_REAL_VECTOR__FormantPath_listStressOfCandidates, U"FormantPath: List stress of candidates", U"") {
+	REAL (tmin, U"left Time range (s)", U"0.0")
+	REAL (tmax, U"right Time range (s)", U"0.0 (=all)")
+	NATURALVECTOR (parameters, U"Coefficients by track", WHITESPACE_SEPARATED_, U"3 3 3")
+	POSITIVE (powerf, U"Power", U"1.25")
+	OK
+DO
+	QUERY_ONE_FOR_REAL_VECTOR (FormantPath)
+		autoVEC result = FormantPath_getStressOfCandidates (me, tmin, tmax, 0, 0, parameters, powerf);
+	QUERY_ONE_FOR_REAL_VECTOR_END
+}
+
+FORM (MODIFY_EACH__FormantPath_setPath, U"FormantPath: Set path", U"") {
+	REAL (tmin, U"left Time range (s)", U"0.0")
+	REAL (tmax, U"right Time range (s)", U"0.0 (=all)")
+	NATURAL (candidate, U"Candidate number", U"5")
+	OK
+DO
+	MODIFY_EACH (FormantPath)
+		FormantPath_setPath	(me, tmin, tmax, candidate);
+	MODIFY_EACH_END	
+}
+
+FORM (MODIFY_EACH__FormantPath_setOptimalPath, U"", U"") {
+	REAL (tmin, U"left Time range (s)", U"0.0")
+	REAL (tmax, U"right Time range (s)", U"0.0 (=all)")
+	NATURALVECTOR (parameters, U"Coefficients by track", WHITESPACE_SEPARATED_, U"3 3 3")
+	POSITIVE (powerf, U"Power", U"1.25")
+	OK
+DO
+	MODIFY_EACH (FormantPath)
+		FormantPath_setOptimalPath (me, tmin, tmax, parameters, powerf);
+	MODIFY_EACH_END
+}
+
 FORM (CONVERT_EACH_TO_ONE__FormantPath_to_Matrix_stress, U"FormantPath: To Matrix (stress)", nullptr) {
 	POSITIVE (windowLength, U"Window length", U"0.025")
 	NATURALVECTOR (parameters, U"Coefficients by track", WHITESPACE_SEPARATED_, U"3 3 3 3")
@@ -276,19 +336,26 @@ DIRECT (CONVERT_EACH_TO_ONE__FormantPath_extractFormant) {
 }
 
 DIRECT (EDITOR_ONE_WITH_ONE_AND_ONE__Sound_TextGrid_FormantPath_createFormantPathEditor) {
-	EDITOR_ONE_WITH_ONE_AND_ONE (a,FormantPath, Sound, TextGrid)
+	EDITOR_ONE_WITH_ONE_AND_ONE (a, FormantPath, Sound, TextGrid)
 		autoFormantPathEditor editor = FormantPathEditor_create (ID_AND_FULL_NAME, me, you, him);
 		Editor_setPublicationCallback (editor.get(), cb_FormantPathEditor_publication);
 	EDITOR_ONE_WITH_ONE_AND_ONE_END
 }
 
 DIRECT (EDITOR_ONE_WITH_ONE_Sound_FormantPath_createFormantPathEditor) {
-	EDITOR_ONE_WITH_ONE (a,FormantPath, Sound)
+	EDITOR_ONE_WITH_ONE (a, FormantPath, Sound)
 		autoFormantPathEditor editor = FormantPathEditor_create (ID_AND_FULL_NAME, me, you, nullptr);
 		Editor_setPublicationCallback (editor.get(), cb_FormantPathEditor_publication);
 	EDITOR_ONE_WITH_ONE_END
 }
 
+DIRECT (EDITOR_ONE_WITH_ONE_TextGrid_FormantPath_createFormantPathEditor) {
+	EDITOR_ONE_WITH_ONE (a, FormantPath, TextGrid)
+		autoFormantPathEditor editor = FormantPathEditor_create (ID_AND_FULL_NAME, me, nullptr, you);
+		Editor_setPublicationCallback (editor.get(), cb_FormantPathEditor_publication);
+	EDITOR_ONE_WITH_ONE_END
+}
+
 /********************** Cepstrum  ****************************************/
 
 DIRECT (CONVERT_EACH_TO_ONE__Cepstrum_downto_PowerCepstrum) {
@@ -355,7 +422,7 @@ DO
 FORM (QUERY_ONE_FOR_REAL__PowerCepstrum_getPeak, U"PowerCepstrum: Get peak", U"PowerCepstrum: Get peak...") {
 	REAL (fromPitch, U"left Search peak in pitch range (Hz)", U"60.0")
 	REAL (toPitch, U"right Search peak in pitch range (Hz)", U"333.3")
-	RADIO_ENUM (kVector_peakInterpolation, peakInterpolationType,
+	CHOICE_ENUM (kVector_peakInterpolation, peakInterpolationType,
 			U"Interpolation", kVector_peakInterpolation :: PARABOLIC)
 	OK
 DO
@@ -368,7 +435,7 @@ DO
 FORM (QUERY_ONE_FOR_REAL__PowerCepstrum_getPeakInQuefrencyInterval, U"", nullptr) {
 	REAL (fromQuefrency, U"left Quefrency interval (s)", U"0.0033 (=300 Hz)")
 	REAL (toQuefrency, U"right Quefrency interval (s)", U"0.01667 (=60 Hz)")
-	RADIO_ENUM (kCepstrum_peakInterpolation, peakInterpolationType,
+	CHOICE_ENUM (kCepstrum_peakInterpolation, peakInterpolationType,
 			U"Interpolation", kCepstrum_peakInterpolation :: PARABOLIC)
 	OK
 DO
@@ -381,7 +448,7 @@ DO
 FORM (QUERY_ONE_FOR_REAL__PowerCepstrum_getQuefrencyOfPeak, U"PowerCepstrum: Get quefrency of peak", U"PowerCepstrum: Get quefrency of peak...") {
 	REAL (fromPitch, U"left Search peak in pitch range (Hz)", U"60.0")
 	REAL (toPitch, U"right Search peak in pitch range (Hz)", U"333.3")
-	RADIO_ENUM (kVector_peakInterpolation, peakInterpolationType,
+	CHOICE_ENUM (kVector_peakInterpolation, peakInterpolationType,
 			U"Interpolation", kVector_peakInterpolation :: PARABOLIC)
 	OK
 DO
@@ -494,7 +561,7 @@ DO
 FORM (QUERY_ONE_FOR_REAL__PowerCepstrum_getPeakProminence, U"PowerCepstrum: Get peak prominence", U"PowerCepstrum: Get peak prominence...") {
 	REAL (fromPitch, U"left Search peak in pitch range (Hz)", U"60.0")
 	REAL (toPitch, U"right Search peak in pitch range (Hz)", U"333.3")
-	RADIO_ENUM (kVector_peakInterpolation, peakInterpolationType,
+	CHOICE_ENUM (kVector_peakInterpolation, peakInterpolationType,
 			U"Interpolation", kVector_peakInterpolation :: PARABOLIC)
 	REAL (fromQuefrency_trendLine, U"left Trend line quefrency range (s)", U"0.001")
 	REAL (toQuefrency_trendLine, U"right Trend line quefrency range (s)", U"0.05")
@@ -681,7 +748,7 @@ FORM (QUERY_ONE_FOR_REAL__PowerCepstrogram_getCPPS, U"PowerCepstrogram: Get CPPS
 	REAL (fromPitch, U"left Peak search pitch range (Hz)", U"60.0")
 	REAL (toPitch, U"right Peak search pitch range (Hz)", U"330.0")
 	POSITIVE (tolerance, U"Tolerance (0-1)", U"0.05")
-	RADIO_ENUM (kVector_peakInterpolation, peakInterpolationType,
+	CHOICE_ENUM (kVector_peakInterpolation, peakInterpolationType,
 			U"Interpolation", kVector_peakInterpolation :: PARABOLIC)
 	LABEL (U"Trend line:")
 	REAL (fromQuefrency_trendLine, U"left Trend line quefrency range (s)", U"0.001")
@@ -727,7 +794,7 @@ FORM (LIST__PowerCepstrogram_listCPP, U"PowerCepstrogram: List cepstral peak pro
 	REAL (fromPitch, U"left Peak search pitch range (Hz)", U"60.0")
 	REAL (toPitch, U"right Peak search pitch range (Hz)", U"330.0")
 	POSITIVE (tolerance, U"Tolerance (0-1)", U"0.05")
-	RADIO_ENUM (kVector_peakInterpolation, peakInterpolationType,
+	CHOICE_ENUM (kVector_peakInterpolation, peakInterpolationType,
 			U"Interpolation", kVector_peakInterpolation :: PARABOLIC)
 	REAL (fromQuefrency_trendLine, U"left Trend line quefrency range (s)", U"0.001")
 	REAL (toQuefrency_trendLine, U"right Trend line quefrency range (s)", U"0.05")
@@ -752,7 +819,7 @@ FORM (NEW__PowerCepstrogram_to_Table_CPP, U"PowerCepstrogram: To Table (cepstral
 	REAL (fromPitch, U"left Peak search pitch range (Hz)", U"60.0")
 	REAL (toPitch, U"right Peak search pitch range (Hz)", U"330.0")
 	POSITIVE (tolerance, U"Tolerance (0-1)", U"0.05")
-	RADIO_ENUM (kVector_peakInterpolation, peakInterpolationType,
+	CHOICE_ENUM (kVector_peakInterpolation, peakInterpolationType,
 			U"Interpolation", kVector_peakInterpolation :: PARABOLIC)
 	REAL (fromQuefrency_trendLine, U"left Trend line quefrency range (s)", U"0.001")
 	REAL (toQuefrency_trendLine, U"right Trend line quefrency range (s)", U"0.05")
@@ -801,11 +868,11 @@ FORM (CONVERT_TWO_TO_ONE__Cepstrumc_to_DTW, U"Cepstrumc: To DTW", U"Cepstrumc: T
 	LABEL (U"Boundary conditions for time warp")
 	BOOLEAN (matchBeginPositions, U"Match begin positions", false)
 	BOOLEAN (matchEndPositions, U"Match end positions", false)
-	RADIO (slopeConstraintType, U"Slope constraints", 1)
-		RADIOBUTTON (U"no restriction")
-		RADIOBUTTON (U"1/3 < slope < 3")
-		RADIOBUTTON (U"1/2 < slope < 2")
-		RADIOBUTTON (U"2/3 < slope < 3/2")
+	CHOICE (slopeConstraintType, U"Slope constraints", 1)
+		OPTION (U"no restriction")
+		OPTION (U"1/3 < slope < 3")
+		OPTION (U"1/2 < slope < 2")
+		OPTION (U"2/3 < slope < 3/2")
 	OK
 DO
 	CONVERT_TWO_TO_ONE (Cepstrumc)
@@ -1198,6 +1265,26 @@ DO
 	CONVERT_EACH_TO_ONE_END (my name.get())
 }
 
+FORM (CONVERT_EACH_TO_ONE__Sound_to_FormantPath_robust, U"Sound: To FormantPath (robust)", U"Sound: To FormantPath (burg)...") {
+	REAL (timeStep, U"Time step (s)", U"0.005")
+	POSITIVE (maximumNumberOfFormants, U"Max. number of formants", U"5.0")
+	REAL (middleFormantCeiling, U"Middle formant ceiling (Hz)", U"5500.0 (= adult female)")
+	POSITIVE (windowLength, U"Window length (s)", U"0.025")
+	POSITIVE (preEmphasisFrequency, U"Pre-emphasis from (Hz)", U"50.0")
+	POSITIVE (numberOfStandardDeviations, U"Number of std. dev.", U"1.5")
+	NATURAL (maximumNumberOfIterations, U"Maximum number of iterations", U"5")
+	REAL (tolerance, U"Tolerance", U"0.000001")
+	LABEL (U"The maximum and minimum ceilings are determined as:")
+	LABEL (U" middleCeiling * exp(+/- ceilingStepSize * numberOfStepsToACeiling).")
+	POSITIVE (ceilingStepSize, U"Ceiling step size", U"0.05")
+	NATURAL (numberOfStepsToACeiling, U"Number of steps up / down", U"4")
+	OK
+DO
+	CONVERT_EACH_TO_ONE (Sound)
+		autoFormantPath result = Sound_to_FormantPath_robust (me, timeStep, maximumNumberOfFormants, middleFormantCeiling, windowLength, preEmphasisFrequency, numberOfStandardDeviations, maximumNumberOfIterations, tolerance, ceilingStepSize, numberOfStepsToACeiling);
+	CONVERT_EACH_TO_ONE_END (my name.get())
+}
+
 #define Sound_to_LPC_addWarning \
 	LABEL (U"Warning 1:  for formant analysis, use \"To Formant\" instead.") \
 	LABEL (U"Warning 2:  if you do use \"To LPC\", you may want to resample first.") \
@@ -1482,7 +1569,7 @@ void praat_uvafon_LPC_init () {
 			HINT__FormantPath_Sound_viewAndEdit);
 	praat_addAction1 (classFormantPath, 1, U"Draw as grid...", nullptr,0, 
 			GRAPHICS_EACH__FormantPath_drawAsGrid);	
-	praat_addAction1 (classFormantPath, 0, U"Tabulate - " , nullptr, 0, nullptr);
+	praat_addAction1 (classFormantPath, 0, U"Tabulate -" , nullptr, 0, nullptr);
 		praat_addAction1 (classFormantPath, 0, U"Down to Table (optimal interval)...", nullptr, 1,
 			NEW__FormantPath_downTo_Table_optimalInterval);
 		praat_addAction1 (classFormantPath, 0, U"Down to Table (stresses)...", nullptr, 1,
@@ -1493,6 +1580,17 @@ void praat_uvafon_LPC_init () {
 			QUERY_ONE_FOR_REAL__FormantPath_getNumberOfCandidates);
 		praat_addAction1 (classFormantPath, 0, U"List ceiling frequencies", nullptr, 1,
 			QUERY_ONE_FOR_REAL_VECTOR__FormantPath_listCeilingFrequencies);
+		praat_addAction1 (classFormantPath, 0, U"Get stress of candidate...", nullptr, 1,
+			QUERY_ONE_FOR_REAL__FormantPath_getStressOfCandidate);
+		praat_addAction1 (classFormantPath, 0, U"List stress of candidates...", nullptr, 1,
+			QUERY_ONE_FOR_REAL_VECTOR__FormantPath_listStressOfCandidates);
+		praat_addAction1 (classFormantPath, 0, U"Get optimal ceiling...", nullptr, 1,
+			QUERY_ONE_FOR_REAL__FormantPath_getOptimalCeiling);
+	praat_addAction1 (classFormantPath, 0, U"Modify -", nullptr, 0, nullptr);
+		praat_addAction1 (classFormantPath, 0, U"Set path...", nullptr, 1,
+			MODIFY_EACH__FormantPath_setPath);
+		praat_addAction1 (classFormantPath, 0, U"Set optimal path...", nullptr, 1,
+			MODIFY_EACH__FormantPath_setOptimalPath);
 	praat_addAction1 (classFormantPath, 0, U"Extract Formant", nullptr,0, 
 			CONVERT_EACH_TO_ONE__FormantPath_extractFormant);
 	praat_addAction1 (classFormantPath, 0, U"To Matrix (stress)...", nullptr,0, 
@@ -1598,11 +1696,9 @@ void praat_uvafon_LPC_init () {
 			HELP__PowerCepstrum_help);
 	praat_addAction1 (classPowerCepstrum, 0, U"Draw...", nullptr, 0, 
 			GRAPHICS_EACH__PowerCepstrum_draw);
-	praat_addAction1 (classPowerCepstrum, 0, U"Draw trend line...", nullptr, 0, 
-			GRAPHICS_EACH__PowerCepstrum_drawTrendLine);
-	praat_addAction1 (classPowerCepstrum, 0, U"Draw tilt line...", nullptr, GuiMenu_DEPRECATED_2019,
-			GRAPHICS_EACH__PowerCepstrum_drawTrendLine);
-	praat_addAction1 (classCepstrum, 0, U"Draw (linear)...", nullptr, GuiMenu_HIDDEN, 
+	praat_addAction1 (classPowerCepstrum, 0, U"Draw trend line... || Draw tilt line...",
+			nullptr, 0, GRAPHICS_EACH__PowerCepstrum_drawTrendLine);   // alternative GuiMenu_DEPRECATED_2019
+	praat_addAction1 (classCepstrum, 0, U"Draw (linear)...", nullptr, GuiMenu_HIDDEN,
 			GRAPHICS_EACH__Cepstrum_drawLinear);
 	praat_addAction1 (classCepstrum, 0, U"Down to PowerCepstrum", nullptr, 0, 
 			CONVERT_EACH_TO_ONE__Cepstrum_downto_PowerCepstrum);
@@ -1627,39 +1723,29 @@ void praat_uvafon_LPC_init () {
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getPeakInQuefrencyInterval);
 		praat_addAction1 (classPowerCepstrum, 0, U"Get quefrency of peak...", nullptr, 1, 
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getQuefrencyOfPeak);
-		praat_addAction1 (classPowerCepstrum, 0, U"Get peak prominence (hillenbrand)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_HIDDEN,
-				QUERY_ONE_FOR_REAL__PowerCepstrum_getPeakProminence_hillenbrand);
+		praat_addAction1 (classPowerCepstrum, 0, U"Get peak prominence (hillenbrand)...",
+				nullptr, GuiMenu_DEPTH_1 | GuiMenu_HIDDEN, QUERY_ONE_FOR_REAL__PowerCepstrum_getPeakProminence_hillenbrand);
 		praat_addAction1 (classPowerCepstrum, 0, U"Get peak prominence...", nullptr, 1, 
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getPeakProminence);
-		praat_addAction1 (classPowerCepstrum, 0, U"Get trend line slope...", nullptr, 1,
-				QUERY_ONE_FOR_REAL__PowerCepstrum_getTrendLineSlope);
-		praat_addAction1 (classPowerCepstrum, 0, U"Get trend line intercept...", nullptr, 1,
+		praat_addAction1 (classPowerCepstrum, 0, U"Get trend line slope... || Get tilt line slope...",
+				nullptr, 1, QUERY_ONE_FOR_REAL__PowerCepstrum_getTrendLineSlope);
+		praat_addAction1 (classPowerCepstrum, 0, U"Get trend line intercept... || Get tilt line intercept...", nullptr, 1,
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getTrendLineIntercept);
 		praat_addAction1 (classPowerCepstrum, 0, U"Get value in bin...", nullptr, 1,
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getValueInBin);
 		praat_addAction1 (classPowerCepstrum, 0, U"Get rhamonics to noise ratio...", nullptr, 1, 
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getRNR);
-		praat_addAction1 (classPowerCepstrum, 0, U"Get tilt line slope...", nullptr, GuiMenu_DEPRECATED_2019,
-				QUERY_ONE_FOR_REAL__PowerCepstrum_getTrendLineSlope);
-		praat_addAction1 (classPowerCepstrum, 0, U"Get tilt line intercept...", nullptr, GuiMenu_DEPRECATED_2019,
-				QUERY_ONE_FOR_REAL__PowerCepstrum_getTrendLineIntercept);
 	praat_addAction1 (classPowerCepstrum, 1, U"Modify -", nullptr, 0, nullptr);
 		praat_addAction1 (classPowerCepstrum, 0, U"Formula...", nullptr, 1, 
 				MODIFY_EACH__PowerCepstrum_formula);
-		praat_addAction1 (classPowerCepstrum, 0, U"Subtract trend (in-place)...", nullptr, 1, 
-				MODIFY_EACH__PowerCepstrum_subtractTrend_inplace);
-		praat_addAction1 (classPowerCepstrum, 0, U"Subtract tilt (in-line)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_DEPRECATED_2017,
-				MODIFY_EACH__PowerCepstrum_subtractTrend_inplace);
-		praat_addAction1 (classPowerCepstrum, 0, U"Smooth (in-place)...", nullptr, 1, 
-				MODIFY_EACH__PowerCepstrum_smooth_inplace);
-		praat_addAction1 (classPowerCepstrum, 0, U"Smooth (in-line)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_DEPRECATED_2017,
-				MODIFY_EACH__PowerCepstrum_smooth_inplace);
+		praat_addAction1 (classPowerCepstrum, 0, U"Subtract trend (in-place)... || Subtract tilt (in-line)...",
+				nullptr, 1, MODIFY_EACH__PowerCepstrum_subtractTrend_inplace);   // alternative GuiMenu_DEPRECATED_2017
+		praat_addAction1 (classPowerCepstrum, 0, U"Smooth (in-place)... || Smooth (in-line)...",
+				nullptr, 1, MODIFY_EACH__PowerCepstrum_smooth_inplace);   // alternative GuiMenu_DEPRECATED_2017
 
-	praat_addAction1 (classPowerCepstrum, 0, U"Subtract trend...", nullptr, 0, 
-			CONVERT_EACH_TO_ONE__PowerCepstrum_subtractTrend);
-	praat_addAction1 (classPowerCepstrum, 0, U"Subtract tilt...", nullptr, GuiMenu_DEPRECATED_2019,
-			CONVERT_EACH_TO_ONE__PowerCepstrum_subtractTrend);
-	praat_addAction1 (classPowerCepstrum, 0, U"Smooth...", nullptr, 0, 
+	praat_addAction1 (classPowerCepstrum, 0, U"Subtract trend... || Subtract tilt...",
+			nullptr, 0, CONVERT_EACH_TO_ONE__PowerCepstrum_subtractTrend);   // alternative GuiMenu_DEPRECATED_2019
+	praat_addAction1 (classPowerCepstrum, 0, U"Smooth...", nullptr, 0,
 			CONVERT_EACH_TO_ONE__PowerCepstrum_smooth);
 	praat_addAction1 (classCepstrum, 0, U"To Spectrum", nullptr, GuiMenu_HIDDEN,
 			CONVERT_EACH_TO_ONE__Cepstrum_to_Spectrum);
@@ -1671,8 +1757,10 @@ void praat_uvafon_LPC_init () {
 	praat_addAction1 (classPowerCepstrogram, 0, U"Paint...", nullptr, 0, 
 			GRAPHICS_EACH__PowerCepstrogram_paint);
 	praat_addAction1 (classPowerCepstrogram, 0, U"Tabulate -", nullptr, 0, nullptr);
-		praat_addAction1 (classPowerCepstrogram, 1, U"List cepstral peak prominences...", nullptr, 1, LIST__PowerCepstrogram_listCPP);
-		praat_addAction1 (classPowerCepstrogram, 0, U"To Table (cepstral peak prominences)...", nullptr, 1, NEW__PowerCepstrogram_to_Table_CPP);
+		praat_addAction1 (classPowerCepstrogram, 1, U"List cepstral peak prominences...",
+				nullptr, 1, LIST__PowerCepstrogram_listCPP);
+		praat_addAction1 (classPowerCepstrogram, 0, U"To Table (cepstral peak prominences)...",
+				nullptr, 1, NEW__PowerCepstrogram_to_Table_CPP);
 	praat_addAction1 (classPowerCepstrogram, 0, U"To Table (hillenbrand)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_HIDDEN,
 			CONVERT_EACH_TO_ONE__PowerCepstrogram_to_Table_hillenbrand);
 	praat_addAction1 (classPowerCepstrogram, 1, U"Query -", nullptr, 0, nullptr);
@@ -1687,29 +1775,25 @@ void praat_uvafon_LPC_init () {
 					QUERY_ONE_FOR_INTEGER__PowerCepstrogram_getNumberOfQuefrencyBins);
 			praat_addAction1 (classPowerCepstrogram, 1, U"Get quefrency step", nullptr, 2,
 					QUERY_ONE_FOR_REAL__PowerCepstrogram_getQuefrencyStep);
-		praat_addAction1 (classPowerCepstrogram, 0, U"Get CPPS (hillenbrand)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_HIDDEN,
-				QUERY_ONE_FOR_REAL__PowerCepstrogram_getCPPS_hillenbrand);
+		praat_addAction1 (classPowerCepstrogram, 0, U"Get CPPS (hillenbrand)...",
+				nullptr, GuiMenu_DEPTH_1 | GuiMenu_HIDDEN, QUERY_ONE_FOR_REAL__PowerCepstrogram_getCPPS_hillenbrand);
 		praat_addAction1 (classPowerCepstrogram, 0, U"Get CPPS...", nullptr, 1,
 				QUERY_ONE_FOR_REAL__PowerCepstrogram_getCPPS);
 	praat_addAction1 (classPowerCepstrogram, 0, U"Modify -", nullptr, 0, nullptr);
 		praat_TimeFunction_modify_init (classPowerCepstrogram);
 		praat_addAction1 (classPowerCepstrogram, 0, U"Formula...", nullptr, 1, 
 				MODIFY__EACH_WEAK__PowerCepstrogram_formula);
-		praat_addAction1 (classPowerCepstrogram, 0, U"Subtract trend (in-place)...", nullptr, 1,
-				MODIFY_EACH__PowerCepstrogram_subtractTrend_inplace);
-		praat_addAction1 (classPowerCepstrogram, 0, U"Subtract tilt (in-place)...", nullptr, GuiMenu_DEPRECATED_2019,
-				MODIFY_EACH__PowerCepstrogram_subtractTrend_inplace);
-		praat_addAction1 (classPowerCepstrogram, 0, U"Subtract tilt (in-line)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_DEPRECATED_2017,
-				MODIFY_EACH__PowerCepstrogram_subtractTrend_inplace);
-	praat_addAction1 (classPowerCepstrogram, 0, U"To PowerCepstrum (slice)...", nullptr, 0, 
+		praat_addAction1 (classPowerCepstrogram, 0,
+			U"Subtract trend (in-place)... || Subtract tilt (in-place)... || Subtract tilt (in-line)...",
+			nullptr, 1, MODIFY_EACH__PowerCepstrogram_subtractTrend_inplace
+		);   // GuiMenu_DEPRECATED_2017/2019
+	praat_addAction1 (classPowerCepstrogram, 0, U"To PowerCepstrum (slice)...", nullptr, 0,
 			CONVERT_EACH_TO_ONE__PowerCepstrogram_to_PowerCepstrum_slice);
 	praat_addAction1 (classPowerCepstrogram, 0, U"Smooth...", nullptr, 0, 
 			CONVERT_EACH_TO_ONE__PowerCepstrogram_smooth);
-	praat_addAction1 (classPowerCepstrogram, 0, U"Subtract trend...", nullptr, 0, 
-			CONVERT_EACH_TO_ONE__PowerCepstrogram_subtractTrend);
-	praat_addAction1 (classPowerCepstrogram, 0, U"Subtract tilt...", nullptr, GuiMenu_DEPRECATED_2019,
-			CONVERT_EACH_TO_ONE__PowerCepstrogram_subtractTrend);
-	praat_addAction1 (classPowerCepstrogram, 0, U"To Matrix", nullptr, 0, 
+	praat_addAction1 (classPowerCepstrogram, 0, U"Subtract trend... || Subtract tilt...",
+			nullptr, 0, CONVERT_EACH_TO_ONE__PowerCepstrogram_subtractTrend);   // alternative GuiMenu_DEPRECATED_2019
+	praat_addAction1 (classPowerCepstrogram, 0, U"To Matrix", nullptr, 0,
 			CONVERT_EACH_TO_ONE__PowerCepstrogram_to_Matrix);
 
 	praat_addAction1 (classSound, 0, U"To PowerCepstrogram...", U"To Harmonicity (gne)...", 1, 
@@ -1722,6 +1806,8 @@ void praat_uvafon_LPC_init () {
 			CONVERT_EACH_TO_ONE__Sound_to_FormantPath);
 	praat_addAction1 (classSound, 0, U"To FormantPath (burg)...", U"To FormantPath...", 1, 
 			CONVERT_EACH_TO_ONE__Sound_to_FormantPath_burg);
+	praat_addAction1 (classSound, 0, U"To FormantPath (robust)...", U"To FormantPath (burg)...", GuiMenu_DEPTH_1 | GuiMenu_HIDDEN, 
+			CONVERT_EACH_TO_ONE__Sound_to_FormantPath_robust);
 	praat_addAction1 (classSound, 0, U"To LPC", U"To FormantPath...", 1, nullptr);
 	praat_addAction1 (classSound, 0, U"To LPC (autocorrelation)...", U"To LPC", 2,
 			CONVERT_EACH_TO_ONE__Sound_to_LPC_autocorrelation);
@@ -1735,6 +1821,8 @@ void praat_uvafon_LPC_init () {
 			CONVERT_EACH_TO_ONE__Sound_to_MFCC);
 	praat_addAction2 (classSound, 1, classFormantPath, 1, U"View & Edit", nullptr,0,
 			EDITOR_ONE_WITH_ONE_Sound_FormantPath_createFormantPathEditor);
+	praat_addAction2 (classTextGrid, 1, classFormantPath, 1, U"View & Edit", nullptr,0,
+			EDITOR_ONE_WITH_ONE_TextGrid_FormantPath_createFormantPathEditor);
 	praat_addAction3 (classSound, 1, classTextGrid, 1, classFormantPath, 1, U"View & Edit", nullptr, 0,
 			EDITOR_ONE_WITH_ONE_AND_ONE__Sound_TextGrid_FormantPath_createFormantPathEditor);
 	
