@@ -1,6 +1,6 @@
 /* Permutation.cpp
  *
- * Copyright (C) 2005-2020 David Weenink
+ * Copyright (C) 2005-2022 David Weenink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -103,10 +103,12 @@ void Permutation_tableJump_inline (Permutation me, integer jumpSize, integer fir
 	}
 }
 
-autoPermutation Permutation_create (integer numberOfElements) {
+autoPermutation Permutation_create (integer numberOfElements, bool identity) {
 	try {
 		autoPermutation me = Thing_new (Permutation);
 		Permutation_init (me.get(), numberOfElements);
+		if (! identity)
+			Permutation_permuteRandomly_inplace (me.get(), 1, numberOfElements);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Permutation not created.");
@@ -168,6 +170,21 @@ void Permutation_swapBlocks (Permutation me, integer from, integer to, integer b
 	}
 }
 
+autoPermutation Permutation_permutePartByOther (Permutation me, integer startPosition, Permutation other) {
+	Melder_require (startPosition > 0 && startPosition <= my numberOfElements,
+		U"The start position should be in the range from 1 to ", my numberOfElements, U".");
+	const integer endPosition = startPosition + other -> numberOfElements - 1;
+	Melder_require (endPosition <= my numberOfElements,
+		U"Start at position ", startPosition, U" requires the permuter to have maximally ",
+		my numberOfElements - startPosition + 1, U" elements, however it has ", other -> numberOfElements,
+		U" elements. "
+	);
+	autoPermutation thee = Data_copy (me);
+	for (integer ipos = 1; ipos <= other -> numberOfElements; ipos ++)
+		thy p [startPosition + ipos - 1] = my p [startPosition + other -> p [ipos] - 1];
+	return thee;
+}
+
 void Permutation_permuteRandomly_inplace (Permutation me, integer from, integer to) {
 	try {
 		const integer n = Permutation_checkRange (me, & from, & to);
@@ -245,9 +262,8 @@ autoPermutation Permutation_permuteBlocksRandomly (Permutation me, integer from,
 		Melder_require (nrest == 0,
 			U"There should fit an integer number of blocks in the range.\n(The last block is only of size ", nrest, U").");
 		
-		autoPermutation pblocks = Permutation_create (nblocks);
+		autoPermutation pblocks = Permutation_create (nblocks, true);
 
-		Permutation_permuteRandomly_inplace (pblocks.get(), 1, nblocks);
 		integer first = from;
 		for (integer iblock = 1; iblock <= nblocks; iblock ++, first += blockSize) {
 			/* (n1,n2,n3,...) means: move block n1 to position 1 etc... */
@@ -429,4 +445,108 @@ autoPermutation Permutations_multiply (OrderedOf<structPermutation>* me) {
 	}
 }
 
+static void checkUniqueAndInInterval (constINTVEC const& vec, integer maximum) {
+	autoINTVEC sorted = sort_INTVEC (vec);
+	Melder_require (sorted [1] >= 1 && vec [sorted.size] <= maximum,
+		U"The subset numbers should  be in the interval from 1 to ", maximum, U".");
+	for (integer i = 2; i <= sorted.size; i ++)
+		if (sorted [i] == sorted [i - 1])
+			Melder_throw (U"All numbers in the set should be unique, number ", sorted [i], U" isn't.");
+}
+
+void Permutation_permuteVEC_inout (Permutation me, VEC vec) {
+		try {
+		Melder_require (my numberOfElements == vec.size,
+			U"The sizes of the vector and the Permutation should be equal.");
+		autoVEC save = copy_VEC (vec);
+		for (integer i = 1; i <= my numberOfElements; i ++)
+			vec [i] = save [my p [i]];
+	} catch (MelderError) {
+		Melder_throw (U"Vector not permuted.");
+	}
+
+}
+
+void Permutation_permuteINTVEC_inout (Permutation me, INTVEC vec){
+		try {
+		Melder_require (my numberOfElements == vec.size,
+			U"The sizes of the vector and the Permutation should be equal.");
+		autoINTVEC save = copy_INTVEC (vec);
+		for (integer i = 1; i <= my numberOfElements; i ++)
+			vec [i] = save [my p [i]];
+	} catch (MelderError) {
+		Melder_throw (U"Vector not permuted.");
+	}
+}
+
+void Permutation_permuteSTRVEC_inout (Permutation me, autoSTRVEC & vec) {
+	try {
+		Melder_require (my numberOfElements == vec.size,
+			U"The sizes of the vector and the Permutation should be equal.");
+		autoSTRVEC save = copy_STRVEC (vec.get());
+		for (integer i = 1; i <= my numberOfElements; i ++)
+			vec [i] = save [my p [i]].move();
+	} catch (MelderError) {
+		Melder_throw (U"STRVEC not permuted.");
+	}
+}
+
+void Permutation_permuteSubsetByOther_inout (Permutation me, constINTVEC const& subsetPositions, Permutation other) {
+	try {
+		autoPermutation thee = Data_copy (me);
+		Melder_require (subsetPositions.size == other -> numberOfElements,
+			U"The subset and the other Permutation should have the same size.");
+		checkUniqueAndInInterval (subsetPositions, my numberOfElements);
+		autoINTVEC save = raw_INTVEC (subsetPositions.size);
+		for (integer i = 1; i <= subsetPositions.size; i ++)
+			save [i] = my p [subsetPositions [i]];
+		
+		for (integer i = 1; i <= subsetPositions.size; i ++)
+			my p [subsetPositions [i]] =  save [other -> p [i]];
+	} catch (MelderError) {
+		Melder_throw (me, U": not permuted by subset");
+	}
+}
+
+autoPermutation Permutation_moveElementsToTheFront (Permutation me, constINTVEC const& subsetPositions) {
+	try {
+		if (subsetPositions.size == 0) {
+			return Data_copy (me);
+		}
+		checkUniqueAndInInterval (subsetPositions, my numberOfElements);
+		autoPermutation thee = Data_copy (me);
+		for (integer i = 1; i <= subsetPositions.size; i++)
+			thy p [i] = my p [subsetPositions [i]];
+		integer nextPos = subsetPositions.size;
+		// remove the duplicates
+		for (integer i = 1; i <= my numberOfElements; i ++) {
+			bool inSubset = false;
+			for (integer j = 1; j <= subsetPositions.size; j++)
+				if (my p [i] == thy p [j]) {
+					inSubset = true;
+					break;
+				}
+			if (! inSubset)
+				thy p [++ nextPos] = my p [i];
+		}
+		Melder_assert (nextPos == my numberOfElements);
+		return thee;
+	} catch (MelderError) {
+		Melder_throw (me, U": not permuted by subset");
+	}
+}
+
+autoPermutation Permutation_createAsSortingIndex (constSTRVEC const& strvec, kStrings_sorting sorting) {
+	try {
+		autoPermutation me = Permutation_create (strvec.size, true);
+		if (sorting == kStrings_sorting::ALPHABETICAL) 
+			INTVECindex_inout (my p.get(), strvec);
+		else if (sorting == kStrings_sorting::NUMBER_AWARE)
+			INTVECindex_numberAware_inout (my p.get(), strvec);
+		return me;
+	} catch (MelderError) {
+		Melder_throw (U"Could not create Permutation from STRVEC.");
+	}	
+}
+
 /* End of Permutation.cpp */
