@@ -51,14 +51,13 @@
 
 Thing_implement (GaussianMixture, Daata, 0);
 
-void structGaussianMixture :: v_info () {
-	our structDaata :: v_info ();
+void structGaussianMixture :: v1_info () {
+	structDaata :: v1_info ();
 	MelderInfo_writeLine (U"Number of components: ", our numberOfComponents);
 	MelderInfo_writeLine (U"Dimension of component: ", our dimension);
 	MelderInfo_writeLine (U"Mixing probabilities:");
-	for (integer im = 1; im <= numberOfComponents; im ++) {
+	for (integer im = 1; im <= numberOfComponents; im ++)
 		MelderInfo_writeLine (U"  ", im, U": p = ", our mixingProbabilities [im], U"  Name =  \"", Thing_getName (our covariances->at [im]), U"\"");
-	}
 }
 
 static integer GaussianMixture_getNumberOfParametersInComponent (GaussianMixture me) {
