@@ -63,9 +63,17 @@ void Sound_overwritePart (Sound me, double t1, double t2, Sound thee, double t3)
 	starting at t3 in thee.
 */
 
+autoSound Sound_derivative (Sound me, double lowPassFrequency, double smoothing, bool peak99);
+/*
+	The real derivative
+*/
+
 void Sound_preEmphasis (Sound me, double preEmphasisFrequency);
-/* deEmphasis = exp(- 2 * NUMpi * deEmphasisFrequency * my dx); */
-/* for (i=my nx; i >=2; i-- ) my z [1] [i] -= preEmphasis * my z [1] [i-1]; */
+/*
+	Approximation of derivative by first order difference.
+	deEmphasis = exp(- 2 * NUMpi * deEmphasisFrequency * my dx);
+	for (i=my nx; i >=2; i-- ) my z [1] [i] -= preEmphasis * my z [1] [i-1];
+*/
 
 void Sound_deEmphasis (Sound me, double preEmphasisFrequency);
 /*	for (i=2; i <= my nx; i++ ) my z [1] [i] += deEmphasis * my z [1] [i-1]; */
@@ -128,8 +136,8 @@ void Sound_scale_dB (Sound me, double level_dB);
 */
 
 void Sound_fade (Sound me, int channel, double t, double fadeTime, bool fadeOut, bool fadeGlobal);
-/* if inout <= 0 fade in with (1-cos)/2  else fade out with (1+cos)/2
-	channel = 0 (all), 1 (left), 2 (right).
+/* if !fadeOut fade in with (1-cos)/2  else fade out with (1+cos)/2
+	channel = 0 (all).
 */
 
 void Sound_draw_btlr (Sound me, Graphics g, double tmin, double tmax, double amin, double amax, kSoundDrawingDirection drawingDirection, bool garnish);
