@@ -64,7 +64,7 @@ void structMelSpectrogram :: v1_info () {
 }
 
 // Preconditions: 1 <= iframe <= nx; 1 <= irow <= ny
-double structBandFilterSpectrogram :: v_getValueAtSample (integer iframe, integer ifreq, int units) {
+double structBandFilterSpectrogram :: v_getValueAtSample (integer iframe, integer ifreq, int units) const {
 	double val = undefined;
 	if (units == 0)
 		val = z [ifreq] [iframe];
@@ -244,10 +244,7 @@ void BandFilterSpectrogram_paintImage (BandFilterSpectrogram me, Graphics g,
 	double xmin, double xmax, double ymin, double ymax, double minimum, double maximum, bool garnish)
 {
 	Function_unidirectionalAutowindow (me, & xmin, & xmax);
-	if (ymax <= ymin) {
-		ymin = my ymin;
-		ymax = my ymax;
-	}
+	SampledXY_unidirectionalAutowindowY (me, & ymin, & ymax);
 	integer ixmin, ixmax, iymin, iymax;
 	(void) Matrix_getWindowSamplesX (me, xmin - 0.49999 * my dx, xmax + 0.49999 * my dx, &ixmin, &ixmax);
 	(void) Matrix_getWindowSamplesY (me, ymin - 0.49999 * my dy, ymax + 0.49999 * my dy, &iymin, &iymax);
