@@ -28,6 +28,7 @@
 #include "FileInMemoryManager.h"
 #include "speech.h"
 #include "synthesize.h"
+#include "voice.h"
 #include "espeakdata_FileInMemory.h"
 
 #define SpeechSynthesizer_PHONEMECODINGS_IPA 2
@@ -44,15 +45,10 @@ void EspeakVoice_setDefaults (EspeakVoice me);
 
 void EspeakVoice_initFromEspeakVoice (EspeakVoice me, voice_t *voice);
 
-
 void SpeechSynthesizer_initEspeak ();
 
 autoSpeechSynthesizer SpeechSynthesizer_create (conststring32 languageName, conststring32 voiceName);
 
-conststring32 SpeechSynthesizer_getLanguageCode (SpeechSynthesizer me);
-
-conststring32 SpeechSynthesizer_getVoiceCode (SpeechSynthesizer me);
-
 void SpeechSynthesizer_changeLanguageNameToCurrent (SpeechSynthesizer me);
 
 void SpeechSynthesizer_setTextInputSettings (SpeechSynthesizer me, int inputTextFormat, int inputPhonemeCoding);
