@@ -1,6 +1,6 @@
 /* Strings_extensions.cpp
  *
- * Copyright (C) 1993-2012,2015-2020 David Weenink, 2015-2021 Paul Boersma
+ * Copyright (C) 1993-2012,2015-2022 David Weenink, 2015-2021 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ autoStrings Strings_createFixedLength (integer numberOfStrings) {
 autoStrings Strings_createAsCharacters (conststring32 string) {
 	try {
 		autoStrings me = Thing_new (Strings);
-		my numberOfStrings = str32len (string);
+		my numberOfStrings = Melder_length (string);
 		my strings = autoSTRVEC (my numberOfStrings);
 		for (integer i = 1; i <= my numberOfStrings; i ++)
 			my strings [i] = Melder_dup (Melder_character (*string ++));
@@ -160,12 +160,9 @@ autoStrings Strings_extractPart (Strings me, integer from, integer to) {
 	}
 }
 
-autoPermutation Strings_to_Permutation (Strings me, bool sort) {
+autoPermutation Strings_to_Permutation (Strings me, kStrings_sorting sorting) {
 	try {
-		autoPermutation thee = Permutation_create (my numberOfStrings);
-		if (sort)
-			INTVECindex (thy p.get(), my strings.get());
-		return thee;
+		return Permutation_createAsSortingIndex (my strings.get(), sorting);
 	} catch (MelderError) {
 		Melder_throw (me, U": no Permutation created.");
 	}
@@ -188,7 +185,7 @@ autoStrings Strings_Permutation_permuteStrings (Strings me, Permutation thee) {
 
 autoStringsIndex Stringses_to_StringsIndex (Strings me, Strings classes) {
 	try {
-		autoStringsIndex tmp = Strings_to_StringsIndex (classes);
+		autoStringsIndex tmp = Strings_to_StringsIndex (classes, kStrings_sorting::ALPHABETICAL);
 		const integer numberOfClasses = tmp -> classes->size;
 
 		autoStringsIndex him = StringsIndex_create (my numberOfStrings);
@@ -215,33 +212,11 @@ autoStringsIndex Stringses_to_StringsIndex (Strings me, Strings classes) {
 	}
 }
 
-autoStringsIndex Strings_to_StringsIndex (Strings me) {
-	try {
-		autoStringsIndex thee = StringsIndex_create (my numberOfStrings);
-		autoPermutation sorted = Strings_to_Permutation (me, true);
-		integer numberOfClasses = 0;
-		conststring32 strings = nullptr;
-		for (integer i = 1; i <= sorted -> numberOfElements; i ++) {
-			const integer index = sorted -> p [i];
-			const conststring32 stringsi = my strings [index].get();
-			if (i == 1 || ! Melder_equ (strings, stringsi)) {
-				numberOfClasses ++;
-				autoSimpleString him = SimpleString_create (stringsi);
-				thy classes -> addItem_move (him.move());
-				strings = stringsi;
-			}
-			thy classIndex [index] = numberOfClasses;
-		}
-		return thee;
-	} catch (MelderError) {
-		Melder_throw (me, U": no StringsIndex created.");
-	}
-}
 
 autoStrings StringsIndex_to_Strings (StringsIndex me) {
 	try {
 		autoStrings thee = Strings_createFixedLength (my numberOfItems);
-		for (integer i = 1; i <= thy numberOfStrings; i ++) {
+		for (integer i = 1; i <= my numberOfItems; i ++) {
 			const SimpleString s = (SimpleString) my classes->at [my classIndex [i]];   // FIXME cast, FIXME classIndex
 			thy strings [i] = Melder_dup (s -> string.get());
 		}
@@ -251,7 +226,7 @@ autoStrings StringsIndex_to_Strings (StringsIndex me) {
 	}
 }
 
-autoStringsIndex Table_to_StringsIndex_column (Table me, integer column) {
+autoStringsIndex Table_to_StringsIndex_column (Table me, integer column, kStrings_sorting sorting) {
 	try {
 		Table_checkSpecifiedColumnNumberWithinRange (me, column);
 		const integer numberOfRows = my rows.size;
@@ -260,8 +235,7 @@ autoStringsIndex Table_to_StringsIndex_column (Table me, integer column) {
 		for (integer irow = 1; irow <= numberOfRows; irow ++)
 			groupLabels [irow] = Melder_dup (my rows.at [irow] -> cells [column]. string.get());   // TODO: no dup
 
-		autoStrings thee = Strings_createFromSTRVEC (groupLabels.get());
-		autoStringsIndex him = Strings_to_StringsIndex (thee.get());
+		autoStringsIndex him = StringsIndex_createFromSTRVEC (groupLabels.get(), sorting);
 		return him;
 	} catch (MelderError) {
 		Melder_throw (me, U"No StringsIndex created from column ", column, U".");
