@@ -2,7 +2,7 @@
 #define _VowelEditor_h_
 /* VowelEditor.h
  *
- * Copyright (C) 2008-2017 David Weenink
+ * Copyright (C) 2008-2017 David Weenink, 2022 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,11 +18,6 @@
  * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
-/*
- djmw 20070130 First
- djmw 20110306 Latest modification.
-*/
-
 #include "RealTier.h"
 #include "Table.h"
 #include "Editor.h"
@@ -51,21 +46,25 @@ Thing_define (VowelEditor, Editor) {
 	GuiText f0TextField, f0SlopeTextField, durationTextField, extendTextField;
 	GuiLabel startInfo, endInfo;
 
-	void v_destroy () noexcept
-		override;
 	bool v_scriptable ()
 		override { return false; }
 	void v_createChildren ()
 		override;
 	void v_createMenus ()
 		override;
-	void v_createHelpMenuItems (EditorMenu menu)
+	void v_createMenuItems_help (EditorMenu menu)
 		override;
 
 	#include "VowelEditor_prefs.h"
+	void v9_repairPreferences () override;
 
+	/* only in cb_mouse: */
+	double anchorTime;
+	double previousX;
+	double previousY;
+	double dt;
 };
 
-autoVowelEditor VowelEditor_create (conststring32 title, Daata data);
+autoVowelEditor VowelEditor_create (conststring32 title);
 
 #endif /* _VowelEditor_h_ */
