@@ -35,10 +35,20 @@
 #include "speak_lib.h"
 #include "encoding.h"
 
-#include "error.h"
-#include "speech.h"
-#include "synthesize.h"
-#include "translate.h"
+#include "dictionary.h"               // for strncpy0
+#include "error.h"                    // for create_file_error_context
+#include "mnemonics.h"               // for LookupMnemName, MNEM_TAB
+#include "phoneme.h"                  // for PHONEME_TAB, PHONEME_TAB_LIST
+#include "readclause.h"               // for Read4Bytes
+#include "spect.h"                    // for SpectFrame, peak_t, SpectSeq
+#include "speech.h"			// for path_home, GetFileLength
+#include "synthdata.h"                // for LoadPhData
+#include "synthesize.h"               // for TUNE, frame_t, CONDITION_IS_OTHER
+#include "translate.h"                // for utf8_out, utf8_in
+#include "voice.h"                    // for LoadVoice, voice
+#include "wavegen.h"                  // for WavegenInit, WavegenSetVoice
+
+#define N_ITEM_STRING 256
 
 typedef struct {
 	unsigned int value;
@@ -49,9 +59,6 @@ NAMETAB *manifest = NULL;
 int n_manifest;
 char phsrc[sizeof(path_home)+40]; // Source: path to the 'phonemes' source file.
 
-extern ESPEAK_NG_API int utf8_in(int *c, const char *buf);
-
-
 typedef struct {
 	const char *mnem;
 	int type;
@@ -318,7 +325,7 @@ static int phoneme_flags;
 #define N_PROCS 50
 int n_procs;
 int proc_addr[N_PROCS];
-char proc_names[40][N_PROCS];
+char proc_names[N_ITEM_STRING+1][N_PROCS];
 
 #define MAX_PROG_BUF 2000
 USHORT *prog_out;
@@ -406,7 +413,7 @@ static int error_count = 0;
 static int resample_count = 0;
 static int resample_fails = 0;
 static int then_count = 0;
-static int after_if = 0;
+static bool after_if = false;
 
 static char current_fname[80];
 
@@ -442,7 +449,7 @@ int if_level;
 typedef struct {
 	USHORT *p_then;
 	USHORT *p_else;
-	int returned;
+	bool returned;
 } IF_STACK;
 IF_STACK if_stack[N_IF_STACK];
 
@@ -461,7 +468,6 @@ enum {
 
 int item_type;
 int item_terminator;
-#define N_ITEM_STRING 256
 char item_string[N_ITEM_STRING];
 
 static int ref_sorter(char **a, char **b)
@@ -494,7 +500,7 @@ static void CompileReport(void)
 	int procedure_num;
 	int prev_mnemonic;
 
-	if (f_report == NULL)
+	if (f_report == NULL || count_references == 0)
 		return;
 
 	// make a list of all the references and sort it
@@ -627,7 +633,7 @@ static MNEM_TAB reserved_phonemes[] = {
 	{ "'!",     phonSTRESS_TONIC }, // stress - emphasized
 	{ "_;_",    phonPAUSE_CLAUSE }, // clause pause
 
-	{ "#@",     phonVOWELTYPES },   // vowel type groups, these should be consecutive
+	{ "#@",     phonVOWELTYPES },   // vowel type groups, these must be consecutive
 	{ "#a",     phonVOWELTYPES+1 },
 	{ "#e",     phonVOWELTYPES+2 },
 	{ "#i",     phonVOWELTYPES+3 },
@@ -791,8 +797,7 @@ static int NextItem(int type)
 
 	if ((c == ')') || (c == ','))
 		c = ' ';
-
-	if (!feof(f_in))
+	else if (!feof(f_in))
 		unget_char(c);
 
 	if (type == tSTRING)
@@ -853,7 +858,7 @@ static int NextItemMax(int max)
 
 static int NextItemBrackets(int type, int control)
 {
-	// Expect a parameter inside parantheses
+	// Expect a parameter inside parentheses
 	// control: bit 0  0= need (
 	//          bit 1  1= allow comma
 
@@ -1196,9 +1201,9 @@ static int LoadWavefile(FILE *f, const char *fname)
 	int max = 0;
 	int length;
 	int sr1, sr2;
-	int failed;
+	bool failed;
 	int len;
-	int resample_wav = 0;
+	bool resample_wav = false;
 	const char *fname2;
 	char fname_temp[100];
 	char msg[120];
@@ -1210,12 +1215,12 @@ static int LoadWavefile(FILE *f, const char *fname)
 	fseek(f, 40, SEEK_SET);
 
 	if ((sr1 != samplerate_native) || (sr2 != sr1*2)) {
+		int fd_temp;
 		char command[sizeof(path_home)+250];
 
-		failed = 0;
+		failed = false;
 
 #if 1
-		int fd_temp;
 		strcpy(fname_temp, "/tmp/espeakXXXXXX");
 		if ((fd_temp = mkstemp(fname_temp)) >= 0)
 			close(fd_temp);
@@ -1233,7 +1238,7 @@ static int LoadWavefile(FILE *f, const char *fname)
 
 		sprintf(command, "sox \"%s/%s.wav\" -r %d -c1 -t wav %s\n", phsrc, fname2, samplerate_native, fname_temp);
 		if (system(command) != 0)
-			failed = 1;
+			failed = true;
 
 		if (failed || (GetFileLength(fname_temp) <= 0)) {
 			if (resample_fails < 2)
@@ -1256,7 +1261,7 @@ static int LoadWavefile(FILE *f, const char *fname)
 		if (f_report != NULL)
 			fprintf(f_report, "resampled  %s\n", fname);
 		resample_count++;
-		resample_wav = 1;
+		resample_wav = true;
 		fseek(f, 40, SEEK_SET); // skip past the WAV header, up to before "data length"
 	}
 
@@ -1328,7 +1333,7 @@ static int LoadWavefile(FILE *f, const char *fname)
 		length++;
 	}
 
-	if (resample_wav != 0) {
+	if (resample_wav == true) {
 		fclose(f);
 		remove(fname_temp);
 	}
@@ -1390,16 +1395,17 @@ static int LoadEnvelope2(FILE *f, const char *fname)
 	unsigned char env[ENV_LEN];
 
 	n_points = 0;
-	(void) fgets(line_buf, sizeof(line_buf), f); // skip first line
-	while (!feof(f)) {
-		if (fgets(line_buf, sizeof(line_buf), f) == NULL)
-			break;
+	if (fgets(line_buf, sizeof(line_buf), f) != NULL) { ; // skip first line, then loop
+		while (!feof(f)) {
+			if (fgets(line_buf, sizeof(line_buf), f) == NULL)
+				break;
 
-		env_lin[n_points] = 0;
-		n = sscanf(line_buf, "%f %f %d", &env_x[n_points], &env_y[n_points], &env_lin[n_points]);
-		if (n >= 2) {
-			env_x[n_points] *= (float)1.28; // convert range 0-100 to 0-128
-			n_points++;
+			env_lin[n_points] = 0;
+			n = sscanf(line_buf, "%f %f %d", &env_x[n_points], &env_y[n_points], &env_lin[n_points]);
+			if (n >= 2) {
+				env_x[n_points] *= (float)1.28; // convert range 0-100 to 0-128
+				n_points++;
+			}
 		}
 	}
 	if (n_points > 0) {
@@ -1434,7 +1440,7 @@ static int LoadEnvelope2(FILE *f, const char *fname)
 	}
 
 	displ = ftell(f_phdata);
-	fwrite(env, 1, 128, f_phdata);
+	fwrite(env, 1, ENV_LEN, f_phdata);
 
 	return displ;
 }
@@ -1618,20 +1624,20 @@ static void CompileSound(int keyword, int isvowel)
 static int CompileIf(int elif)
 {
 	int key;
-	int finish = 0;
+	bool finish = false;
 	int word = 0;
 	int word2;
 	int data;
 	int bitmap;
 	int brackets;
-	int not_flag;
+	bool not_flag;
 	USHORT *prog_last_if = NULL;
 
 	then_count = 2;
-	after_if = 1;
+	after_if = true;
 
 	while (!finish) {
-		not_flag = 0;
+		not_flag = false;
 		word2 = 0;
 		if (prog_out >= prog_out_max) {
 			error("Phoneme program too large");
@@ -1642,7 +1648,7 @@ static int CompileIf(int elif)
 			error("Expected a condition, not '%s'", item_string);
 
 		if ((item_type == 0) && (key == k_NOT)) {
-			not_flag = 1;
+			not_flag = true;
 			if ((key = NextItem(tCONDITION)) < 0)
 				error("Expected a condition, not '%s'", item_string);
 		}
@@ -1704,7 +1710,7 @@ static int CompileIf(int elif)
 				*prog_last_if |=  i_OR;
 			break;
 		case k_THEN:
-			finish = 1;
+			finish = true;
 			break;
 		default:
 			error("Expected AND, OR, THEN");
@@ -1717,7 +1723,7 @@ static int CompileIf(int elif)
 		if_stack[if_level].p_else = NULL;
 	}
 
-	if_stack[if_level].returned = 0;
+	if_stack[if_level].returned = false;
 	if_stack[if_level].p_then = prog_out;
 	*prog_out++ = i_JUMP_FALSE;
 
@@ -1762,12 +1768,12 @@ static int CompileElse(void)
 		return 0;
 	}
 
-	if (if_stack[if_level].returned == 0)
+	if (if_stack[if_level].returned == false)
 		FillThen(1);
 	else
 		FillThen(0);
 
-	if (if_stack[if_level].returned == 0) {
+	if (if_stack[if_level].returned == false) {
 		ref = prog_out;
 		*prog_out++ = 0;
 
@@ -1847,7 +1853,7 @@ static PHONEME_TAB_LIST *FindPhonemeTable(const char *string)
 		if (strcmp(phoneme_tab_list2[ix].name, string) == 0)
 			return &phoneme_tab_list2[ix];
 	}
-	error("Unknown phoneme table: '%s'", string);
+	error("compile: unknown phoneme table: '%s'", string);
 	return NULL;
 }
 
@@ -1978,8 +1984,8 @@ static int CompilePhoneme(int compile_phoneme)
 	prog_out = prog_buf;
 	prog_out_max = &prog_buf[MAX_PROG_BUF-1];
 	if_level = 0;
-	if_stack[0].returned = 0;
-	after_if = 0;
+	if_stack[0].returned = false;
+	after_if = false;
 	phoneme_flags = 0;
 
 	NextItem(tSTRING);
@@ -2071,7 +2077,7 @@ static int CompilePhoneme(int compile_phoneme)
 				if (phoneme_out->type == phVOWEL)
 					value = (value * vowel_length_factor)/100;
 
-				if (after_if == 0)
+				if (after_if == false)
 					phoneme_out->std_length = value/2;
 				else {
 					*prog_out++ = (i_SET_LENGTH << 8) + value/2;
@@ -2154,14 +2160,14 @@ static int CompilePhoneme(int compile_phoneme)
 					phcode = LookupPhoneme(item_string, 1);
 				phoneme_out->start_type = phcode;
 				if (phoneme_out->type == phINVALID)
-					error("a phoneme type or manner of articulation should be specified before starttype");
+					error("a phoneme type or manner of articulation must be specified before starttype");
 				break;
 			case kENDTYPE:
 				phcode = NextItem(tPHONEMEMNEM);
 				if (phcode == -1)
 					phcode = LookupPhoneme(item_string, 1);
 				if (phoneme_out->type == phINVALID)
-					error("a phoneme type or manner of articulation should be specified before endtype");
+					error("a phoneme type or manner of articulation must be specified before endtype");
 				else if (phoneme_out->type == phVOWEL)
 					phoneme_out->end_type = phcode;
 				else if (phcode != phoneme_out->start_type)
@@ -2209,7 +2215,7 @@ static int CompilePhoneme(int compile_phoneme)
 				DecThenCount();
 				break;
 			case kFMT:
-				if_stack[if_level].returned = 1;
+				if_stack[if_level].returned = true;
 				DecThenCount();
 				if (phoneme_out->type == phVOWEL)
 					CompileSound(keyword, 1);
@@ -2217,7 +2223,7 @@ static int CompilePhoneme(int compile_phoneme)
 					CompileSound(keyword, 0);
 				break;
 			case kWAV:
-				if_stack[if_level].returned = 1;
+				if_stack[if_level].returned = true;
 				// fallthrough:
 			case kVOWELSTART:
 			case kVOWELENDING:
@@ -2254,7 +2260,7 @@ static int CompilePhoneme(int compile_phoneme)
 				endphoneme = 1;
 				if (if_level > 0)
 					error("Missing ENDIF");
-				if ((prog_out > prog_buf) && (if_stack[0].returned == 0))
+				if ((prog_out > prog_buf) && (if_stack[0].returned == false))
 					*prog_out++ = INSTN_RETURN;
 				break;
 			}
@@ -2536,7 +2542,7 @@ espeak_ng_CompilePhonemeDataPath(long rate,
 
 	samplerate_native = samplerate = rate;
 	LoadPhData(NULL, NULL);
-	if (LoadVoice("", 0) == NULL)
+	if (LoadVoice("", 8/*compiling phonemes*/) == NULL)
 		return ENS_VOICE_NOT_FOUND;
 
 	WavegenInit(rate, 0);
@@ -2718,9 +2724,9 @@ espeak_ng_STATUS espeak_ng_CompileIntonation(FILE *log, espeak_ng_ERROR_CONTEXT
 	char c;
 	int keyword;
 	int n_tune_names = 0;
-	int done_split = 0;
-	int done_onset = 0;
-	int done_last = 0;
+	bool done_split = false;
+	bool done_onset = false;
+	bool done_last = false;
 	int n_preset_tunes = 0;
 	int found = 0;
 	int tune_number = 0;
@@ -2806,7 +2812,7 @@ espeak_ng_STATUS espeak_ng_CompileIntonation(FILE *log, espeak_ng_ERROR_CONTEXT
 		switch (keyword)
 		{
 		case kTUNE:
-			done_split = 0;
+			done_split = false;
 
 			memcpy(&new_tune, &default_tune, sizeof(TUNE));
 			NextItem(tSTRING);
@@ -2831,11 +2837,11 @@ espeak_ng_STATUS espeak_ng_CompileIntonation(FILE *log, espeak_ng_ERROR_CONTEXT
 			break;
 		case kENDTUNE:
 			if (!found) continue;
-			if (done_onset == 0) {
+			if (done_onset == false) {
 				new_tune.unstr_start[0] = new_tune.unstr_start[1];
 				new_tune.unstr_end[0] = new_tune.unstr_end[1];
 			}
-			if (done_last == 0) {
+			if (done_last == false) {
 				new_tune.unstr_start[2] = new_tune.unstr_start[1];
 				new_tune.unstr_end[2] = new_tune.unstr_end[1];
 			}
@@ -2849,13 +2855,13 @@ espeak_ng_STATUS espeak_ng_CompileIntonation(FILE *log, espeak_ng_ERROR_CONTEXT
 			new_tune.onset = NextItem(tNUMBER);
 			new_tune.unstr_start[0] = NextItem(tSIGNEDNUMBER);
 			new_tune.unstr_end[0] = NextItem(tSIGNEDNUMBER);
-			done_onset = 1;
+			done_onset = true;
 			break;
 		case kTUNE_HEADLAST:
 			new_tune.head_last = NextItem(tNUMBER);
 			new_tune.unstr_start[2] = NextItem(tSIGNEDNUMBER);
 			new_tune.unstr_end[2] = NextItem(tSIGNEDNUMBER);
-			done_last = 1;
+			done_last = true;
 			break;
 		case kTUNE_HEADENV:
 			NextItem(tSTRING);
@@ -2919,7 +2925,7 @@ espeak_ng_STATUS espeak_ng_CompileIntonation(FILE *log, espeak_ng_ERROR_CONTEXT
 				error("Bad envelope name: '%s'", item_string);
 				break;
 			}
-			done_split = 1;
+			done_split = true;
 			new_tune.split_nucleus_env = ix;
 			new_tune.split_nucleus_max = NextItem(tNUMBER);
 			new_tune.split_nucleus_min = NextItem(tNUMBER);
