@@ -34,13 +34,16 @@
 #include "espeak_ng.h"
 #include "speak_lib.h"
 
-#include "speech.h"
 #include "klatt.h"
+#include "synthesize.h"  // for frame_t, WGEN_DATA, STEPSIZE, N_KLATTP, echo...
+#include "voice.h"       // for voice_t, N_PEAKS
+#ifdef INCLUDE_SPEECHPLAYER
+#include "sPlayer.h"
+#endif
 
 extern unsigned char *out_ptr;
 extern unsigned char *out_start;
 extern unsigned char *out_end;
-extern WGEN_DATA wdata;
 static int nsamples;
 static int sample_count;
 
@@ -61,6 +64,7 @@ static double gen_noise(double);
 static double DBtoLIN(long);
 static void frame_init(klatt_frame_ptr);
 static void setabc(long, long, resonator_ptr);
+static void SetSynth_Klatt(int length, frame_t *fr1, frame_t *fr2, voice_t *v, int control);
 static void setzeroabc(long, long, resonator_ptr);
 
 static klatt_frame_t kt_frame;
@@ -68,7 +72,7 @@ static klatt_global_t kt_globals;
 
 #define NUMBER_OF_SAMPLES 100
 
-static int scale_wav_tab[] = { 45, 38, 45, 45, 55 }; // scale output from different voicing sources
+static int scale_wav_tab[] = { 45, 38, 45, 45, 55, 45 }; // scale output from different voicing sources
 
 // For testing, this can be overwritten in KlattInit()
 static short natural_samples2[256] = {
@@ -133,29 +137,20 @@ static double resonator(resonator_ptr r, double input)
 	return (double)x;
 }
 
-static double resonator2(resonator_ptr r, double input)
-{
-	double x;
+/*
+function ANTIRESONATOR
 
-	x = (double)((double)r->a * (double)input + (double)r->b * (double)r->p1 + (double)r->c * (double)r->p2);
-	r->p2 = (double)r->p1;
-	r->p1 = (double)x;
+This is a generic anti-resonator function. The code is the same as resonator
+except that a,b,c need to be set with setzeroabc() and we save inputs in
+p1/p2 rather than outputs. There is currently only one of these - "rnz"
+Output = (rnz.a * input) + (rnz.b * oldin1) + (rnz.c * oldin2)
+*/
 
-	r->a += r->a_inc;
-	r->b += r->b_inc;
-	r->c += r->c_inc;
-	return (double)x;
-}
-
-static double antiresonator2(resonator_ptr r, double input)
+static double antiresonator(resonator_ptr r, double input)
 {
 	double x = (double)r->a * (double)input + (double)r->b * (double)r->p1 + (double)r->c * (double)r->p2;
 	r->p2 = (double)r->p1;
 	r->p1 = (double)input;
-
-	r->a += r->a_inc;
-	r->b += r->b_inc;
-	r->c += r->c_inc;
 	return (double)x;
 }
 
@@ -240,7 +235,7 @@ static double sampled_source(int source_num)
    Converts synthesis parameters to a waveform.
  */
 
-static int parwave(klatt_frame_ptr frame)
+static int parwave(klatt_frame_ptr frame, WGEN_DATA *wdata)
 {
 	double temp;
 	int value;
@@ -253,7 +248,7 @@ static int parwave(klatt_frame_ptr frame)
 	double casc_next_in;
 	double par_glotout;
 	static double noise;
-	static double voicing;
+	static double voiceKlatt;
 	static double vlast;
 	static double glotlast;
 	static double sourc;
@@ -284,16 +279,16 @@ static int parwave(klatt_frame_ptr frame)
 			switch (kt_globals.glsource)
 			{
 			case IMPULSIVE:
-				voicing = impulsive_source();
+				voiceKlatt = impulsive_source();
 				break;
 			case NATURAL:
-				voicing = natural_source();
+				voiceKlatt = natural_source();
 				break;
 			case SAMPLED:
-				voicing = sampled_source(0);
+				voiceKlatt = sampled_source(0);
 				break;
 			case SAMPLED2:
-				voicing = sampled_source(1);
+				voiceKlatt = sampled_source(1);
 				break;
 			}
 
@@ -306,28 +301,34 @@ static int parwave(klatt_frame_ptr frame)
 			// Low-pass filter voicing waveform before downsampling from 4*samrate
 			// to samrate samples/sec.  Resonator f=.09*samrate, bw=.06*samrate
 
-			voicing = resonator(&(kt_globals.rsn[RLP]), voicing);
+			voiceKlatt = resonator(&(kt_globals.rsn[RLP]), voiceKlatt);
 
 			// Increment counter that keeps track of 4*samrate samples per sec
 			kt_globals.nper++;
 		}
 
+		if(kt_globals.glsource==5) {
+			double v=(kt_globals.nper/(double)kt_globals.T0);
+			v=(v*2)-1;
+			voiceKlatt=v*6000;
+		}
+
 		// Tilt spectrum of voicing source down by soft low-pass filtering, amount
 		// of tilt determined by TLTdb
 
-		voicing = (voicing * kt_globals.onemd) + (vlast * kt_globals.decay);
-		vlast = voicing;
+		voiceKlatt = (voiceKlatt * kt_globals.onemd) + (vlast * kt_globals.decay);
+		vlast = voiceKlatt;
 
 		// Add breathiness during glottal open phase. Amount of breathiness
 		// determined by parameter Aturb Use nrand rather than noise because
 		// noise is low-passed.
 
 		if (kt_globals.nper < kt_globals.nopen)
-			voicing += kt_globals.amp_breth * kt_globals.nrand;
+			voiceKlatt += kt_globals.amp_breth * kt_globals.nrand;
 
 		// Set amplitude of voicing
-		glotout = kt_globals.amp_voice * voicing;
-		par_glotout = kt_globals.par_amp_voice * voicing;
+		glotout = kt_globals.amp_voice * voiceKlatt;
+		par_glotout = kt_globals.par_amp_voice * voiceKlatt;
 
 		// Compute aspiration amplitude and add to voicing source
 		aspiration = kt_globals.amp_aspir * noise;
@@ -340,16 +341,16 @@ static int parwave(klatt_frame_ptr frame)
 
 		out = 0;
 		if (kt_globals.synthesis_model != ALL_PARALLEL) {
-			casc_next_in = antiresonator2(&(kt_globals.rsn[Rnz]), glotout);
+			casc_next_in = antiresonator(&(kt_globals.rsn[Rnz]), glotout);
 			casc_next_in = resonator(&(kt_globals.rsn[Rnpc]), casc_next_in);
 			casc_next_in = resonator(&(kt_globals.rsn[R8c]), casc_next_in);
 			casc_next_in = resonator(&(kt_globals.rsn[R7c]), casc_next_in);
 			casc_next_in = resonator(&(kt_globals.rsn[R6c]), casc_next_in);
-			casc_next_in = resonator2(&(kt_globals.rsn[R5c]), casc_next_in);
-			casc_next_in = resonator2(&(kt_globals.rsn[R4c]), casc_next_in);
-			casc_next_in = resonator2(&(kt_globals.rsn[R3c]), casc_next_in);
-			casc_next_in = resonator2(&(kt_globals.rsn[R2c]), casc_next_in);
-			out = resonator2(&(kt_globals.rsn[R1c]), casc_next_in);
+			casc_next_in = resonator(&(kt_globals.rsn[R5c]), casc_next_in);
+			casc_next_in = resonator(&(kt_globals.rsn[R4c]), casc_next_in);
+			casc_next_in = resonator(&(kt_globals.rsn[R3c]), casc_next_in);
+			casc_next_in = resonator(&(kt_globals.rsn[R2c]), casc_next_in);
+			out = resonator(&(kt_globals.rsn[R1c]), casc_next_in);
 		}
 
 		// Excite parallel F1 and FNP by voicing waveform
@@ -374,31 +375,38 @@ static int parwave(klatt_frame_ptr frame)
 		out = outbypas - out;
 
 		out = resonator(&(kt_globals.rsn[Rout]), out);
-		temp = (int)(out * wdata.amplitude * kt_globals.amp_gain0); // Convert back to integer
+		temp = (int)(out * wdata->amplitude * kt_globals.amp_gain0); // Convert back to integer
 
 		// mix with a recorded WAV if required for this phoneme
 		signed char c;
 		int sample;
 
-		if (wdata.mix_wavefile_ix < wdata.n_mix_wavefile) {
-			if (wdata.mix_wave_scale == 0) {
+		if (wdata->mix_wavefile_ix < wdata->n_mix_wavefile) {
+			if (wdata->mix_wave_scale == 0) {
 				// a 16 bit sample
-				c = wdata.mix_wavefile[wdata.mix_wavefile_ix+1];
-				sample = wdata.mix_wavefile[wdata.mix_wavefile_ix] + (c * 256);
-				wdata.mix_wavefile_ix += 2;
+				c = wdata->mix_wavefile[wdata->mix_wavefile_ix+1];
+				sample = wdata->mix_wavefile[wdata->mix_wavefile_ix] + (c * 256);
+				wdata->mix_wavefile_ix += 2;
 			} else {
 				// a 8 bit sample, scaled
-				sample = (signed char)wdata.mix_wavefile[wdata.mix_wavefile_ix++] * wdata.mix_wave_scale;
+				sample = (signed char)wdata->mix_wavefile[wdata->mix_wavefile_ix++] * wdata->mix_wave_scale;
 			}
-			int z2 = sample * wdata.amplitude_v / 1024;
-			z2 = (z2 * wdata.mix_wave_amp)/40;
+			int z2 = sample * wdata->amplitude_v / 1024;
+			z2 = (z2 * wdata->mix_wave_amp)/40;
 			temp += z2;
 		}
 
+		if (kt_globals.fadein < 64) {
+			temp = (temp * kt_globals.fadein) / 64;
+			++kt_globals.fadein;
+		}
+
 		// if fadeout is set, fade to zero over 64 samples, to avoid clicks at end of synthesis
 		if (kt_globals.fadeout > 0) {
 			kt_globals.fadeout--;
 			temp = (temp * kt_globals.fadeout) / 64;
+			if (kt_globals.fadeout == 0)
+				kt_globals.fadein = 0;
 		}
 
 		value = (int)temp + ((echo_buf[echo_tail++]*echo_amp) >> 8);
@@ -419,7 +427,7 @@ static int parwave(klatt_frame_ptr frame)
 			echo_head = 0;
 
 		sample_count++;
-		if (out_ptr >= out_end)
+		if (out_ptr + 2 > out_end)
 			return 1;
 	}
 	return 0;
@@ -710,7 +718,7 @@ static void pitch_synch_par_reset(klatt_frame_ptr frame)
 /*
    function SETABC
 
-   Convert formant freqencies and bandwidth into resonator difference
+   Convert formant frequencies and bandwidth into resonator difference
    equation constants.
  */
 
@@ -737,7 +745,7 @@ static void setabc(long int f, long int bw, resonator_ptr rp)
 /*
    function SETZEROABC
 
-   Convert formant freqencies and bandwidth into anti-resonator difference
+   Convert formant frequencies and bandwidth into anti-resonator difference
    equation constants.
  */
 
@@ -786,9 +794,10 @@ static void setzeroabc(long int f, long int bw, resonator_ptr rp)
 
 static double gen_noise(double noise)
 {
-	static double nlast = 0.0;
+	long temp;
+	static double nlast;
 
-	long temp = (long)getrandom(-8191, 8191);
+	temp = (long)getrandom(-8191, 8191);
 	kt_globals.nrand = (long)temp;
 
 	noise = kt_globals.nrand + (0.75 * nlast);
@@ -835,15 +844,17 @@ static double DBtoLIN(long dB)
 	return (double)(amptable[dB]) * 0.001;
 }
 
-extern voice_t *wvoice;
 static klatt_peaks_t peaks[N_PEAKS];
 static int end_wave;
 static int klattp[N_KLATTP];
 static double klattp1[N_KLATTP];
 static double klattp_inc[N_KLATTP];
 
-static int Wavegen_Klatt(int resume)
+int Wavegen_Klatt(int length, int resume, frame_t *fr1, frame_t *fr2, WGEN_DATA *wdata, voice_t *wvoice)
 {
+	if (resume == 0)
+		SetSynth_Klatt(length, fr1, fr2, wvoice, 1);
+
 	int pk;
 	int x;
 	int ix;
@@ -853,7 +864,7 @@ static int Wavegen_Klatt(int resume)
 		sample_count = 0;
 
 	while (sample_count < nsamples) {
-		kt_frame.F0hz10 = (wdata.pitch * 10) / 4096;
+		kt_frame.F0hz10 = (wdata->pitch * 10) / 4096;
 
 		// formants F6,F7,F8 are fixed values for cascade resonators, set in KlattInit()
 		// but F6 is used for parallel resonator
@@ -901,10 +912,10 @@ static int Wavegen_Klatt(int resume)
 		}
 
 		// advance the pitch
-		wdata.pitch_ix += wdata.pitch_inc;
-		if ((ix = wdata.pitch_ix>>8) > 127) ix = 127;
-		x = wdata.pitch_env[ix] * wdata.pitch_range;
-		wdata.pitch = (x>>8) + wdata.pitch_base;
+		wdata->pitch_ix += wdata->pitch_inc;
+		if ((ix = wdata->pitch_ix>>8) > 127) ix = 127;
+		x = wdata->pitch_env[ix] * wdata->pitch_range;
+		wdata->pitch = (x>>8) + wdata->pitch_base;
 
 		kt_globals.nspfr = (nsamples - sample_count);
 		if (kt_globals.nspfr > STEPSIZE)
@@ -912,7 +923,7 @@ static int Wavegen_Klatt(int resume)
 
 		frame_init(&kt_frame); // get parameters for next frame of speech
 
-		if (parwave(&kt_frame) == 1)
+		if (parwave(&kt_frame, wdata) == 1)
 			return 1; // output buffer is full
 	}
 
@@ -924,24 +935,24 @@ static int Wavegen_Klatt(int resume)
 		end_wave = 0;
 		sample_count -= fade;
 		kt_globals.nspfr = fade;
-		if (parwave(&kt_frame) == 1)
+		if (parwave(&kt_frame, wdata) == 1)
 			return 1; // output buffer is full
 	}
 
 	return 0;
 }
 
-static void SetSynth_Klatt(int length, frame_t *fr1, frame_t *fr2, voice_t *v, int control)
+static void SetSynth_Klatt(int length, frame_t *fr1, frame_t *fr2, voice_t *wvoice, int control)
 {
 	int ix;
-	DOUBLEX next;
+	double next;
 	int qix;
 	int cmd;
 	frame_t *fr3;
 	static frame_t prev_fr;
 
 	if (wvoice != NULL) {
-		if ((wvoice->klattv[0] > 0) && (wvoice->klattv[0] <= 4 )) {
+		if ((wvoice->klattv[0] > 0) && (wvoice->klattv[0] <= 5 )) {
 			kt_globals.glsource = wvoice->klattv[0];
 			kt_globals.scale_wav = scale_wav_tab[kt_globals.glsource];
 		}
@@ -1001,14 +1012,14 @@ static void SetSynth_Klatt(int length, frame_t *fr1, frame_t *fr2, voice_t *v, i
 	nsamples = length;
 
 	for (ix = 1; ix < 6; ix++) {
-		peaks[ix].freq1 = (fr1->ffreq[ix] * v->freq[ix] / 256.0) + v->freqadd[ix];
+		peaks[ix].freq1 = (fr1->ffreq[ix] * wvoice->freq[ix] / 256.0) + wvoice->freqadd[ix];
 		peaks[ix].freq = (int)peaks[ix].freq1;
-		next = (fr2->ffreq[ix] * v->freq[ix] / 256.0) + v->freqadd[ix];
+		next = (fr2->ffreq[ix] * wvoice->freq[ix] / 256.0) + wvoice->freqadd[ix];
 		peaks[ix].freq_inc =  ((next - peaks[ix].freq1) * STEPSIZE) / length;
 
 		if (ix < 4) {
 			// klatt bandwidth for f1, f2, f3 (others are fixed)
-			peaks[ix].bw1 = fr1->bw[ix] * 2;
+			peaks[ix].bw1 = fr1->bw[ix] * 2  * (wvoice->width[ix] / 256.0);
 			peaks[ix].bw = (int)peaks[ix].bw1;
 			next = fr2->bw[ix] * 2;
 			peaks[ix].bw_inc =  ((next - peaks[ix].bw1) * STEPSIZE) / length;
@@ -1047,14 +1058,6 @@ static void SetSynth_Klatt(int length, frame_t *fr1, frame_t *fr2, voice_t *v, i
 	}
 }
 
-int Wavegen_Klatt2(int length, int resume, frame_t *fr1, frame_t *fr2)
-{
-	if (resume == 0)
-		SetSynth_Klatt(length, fr1, fr2, wvoice, 1);
-
-	return Wavegen_Klatt(resume);
-}
-
 void KlattInit()
 {
 
