@@ -29,7 +29,13 @@
 #include "speak_lib.h"
 #include "encoding.h"
 
-#include "speech.h"
+#include "phonemelist.h"
+#include "phoneme.h"     // for PHONEME_TAB, phVOWEL, REPLACE_PHONEMES, phPAUSE
+#include "synthdata.h"   // for InterpretPhoneme, SelectPhonemeTable
+#include "synthesize.h"  // for PHONEME_LIST, PHONEME_LIST2, phoneme_tab
+#include "translate.h"   // for Translator, LANGUAGE_OPTIONS, option_wordgap
+
+#include "phoneme.h"
 #include "synthesize.h"
 #include "translate.h"
 
@@ -48,28 +54,33 @@ static int SubstitutePhonemes(PHONEME_LIST *plist_out)
 	int k;
 	int replace_flags;
 	int n_plist_out = 0;
-	int word_end;
+	bool word_end;
 	PHONEME_LIST2 *plist2;
 	PHONEME_TAB *next = NULL;
+	int deleted_sourceix = -1;
 
 	for (ix = 0; (ix < n_ph_list2) && (n_plist_out < N_PHONEME_LIST); ix++) {
 		plist2 = &ph_list2[ix];
+		if (deleted_sourceix != -1) {
+			plist2->sourceix = deleted_sourceix;
+			deleted_sourceix = -1;
+		}
 
 		// don't do any substitution if the language has been temporarily changed
 		if (!(plist2->synthflags & SFLAG_SWITCHED_LANG)) {
 			if (ix < (n_ph_list2 -1))
 				next = phoneme_tab[ph_list2[ix+1].phcode];
 
-			word_end = 0;
+			word_end = false;
 			if ((plist2+1)->sourceix || ((next != 0) && (next->type == phPAUSE)))
-				word_end = 1;        // this phoneme is the end of a word
+				word_end = true; // this phoneme is the end of a word
 
 			// check whether a Voice has specified that we should replace this phoneme
 			for (k = 0; k < n_replace_phonemes; k++) {
 				if (plist2->phcode == replace_phonemes[k].old_ph) {
 					replace_flags = replace_phonemes[k].type;
 
-					if ((replace_flags & 1) && (word_end == 0))
+					if ((replace_flags & 1) && (word_end == false))
 						continue; // this replacement only occurs at the end of a word
 
 					if ((replace_flags & 2) && ((plist2->stresslevel & 0x7) > 3))
@@ -86,8 +97,10 @@ static int SubstitutePhonemes(PHONEME_LIST *plist_out)
 				}
 			}
 
-			if (plist2->phcode == 0)
+			if (plist2->phcode == 0) {
+				deleted_sourceix = plist2->sourceix;
 				continue; // phoneme has been replaced by NULL, so don't copy it
+			}
 		}
 
 		// copy phoneme into the output list
@@ -99,7 +112,7 @@ static int SubstitutePhonemes(PHONEME_LIST *plist_out)
 	return n_plist_out;
 }
 
-void MakePhonemeList(Translator *tr, int post_pause, int start_sentence)
+void MakePhonemeList(Translator *tr, int post_pause, bool start_sentence)
 {
 	int ix = 0;
 	int j;
@@ -120,6 +133,7 @@ void MakePhonemeList(Translator *tr, int post_pause, int start_sentence)
 	bool inserted;
 	bool deleted;
 	PHONEME_DATA phdata;
+	bool start_of_clause = true;
 
 	int n_ph_list3;
 	PHONEME_LIST *plist3;
@@ -160,12 +174,18 @@ void MakePhonemeList(Translator *tr, int post_pause, int start_sentence)
 	// look for switch of phoneme tables
 	delete_count = 0;
 	current_phoneme_tab = tr->phoneme_tab_ix;
+	int deleted_sourceix = -1;
 	for (j = 0; j < n_ph_list2; j++) {
 		if (current_phoneme_tab != tr->phoneme_tab_ix)
 			plist2[j].synthflags |= SFLAG_SWITCHED_LANG;
 
-		if (delete_count > 0)
+		if (delete_count > 0) {
 			memcpy(&plist2[j-delete_count], &plist2[j], sizeof(plist2[0]));
+			if (deleted_sourceix != -1) {
+				plist2[j-delete_count].sourceix = deleted_sourceix;
+				deleted_sourceix = -1;
+			}
+		}
 
 		if (plist2[j].phcode == phonSWITCH) {
 			if ((!(plist2[j].synthflags & SFLAG_EMBEDDED)) && (
@@ -175,6 +195,8 @@ void MakePhonemeList(Translator *tr, int post_pause, int start_sentence)
 			        )) {
 				// delete this phonSWITCH if it's switching to the current phoneme table, or
 				// delete this phonSWITCH if its followed by another phonSWITCH
+				if (deleted_sourceix == -1 && plist2[j].sourceix != 0)
+					deleted_sourceix = plist2[j].sourceix;
 				delete_count++;
 			} else
 				current_phoneme_tab = plist2[j].tone_ph;
@@ -187,7 +209,7 @@ void MakePhonemeList(Translator *tr, int post_pause, int start_sentence)
 		// set consonant clusters to all voiced or all unvoiced
 		// Regressive
 		int type;
-		int stop_propagation = 0;
+		bool stop_propagation = false;
 		voicing = 0;
 
 		for (j = n_ph_list2-1; j >= 0; j--) {
@@ -196,7 +218,7 @@ void MakePhonemeList(Translator *tr, int post_pause, int start_sentence)
 				continue;
 
 			if (plist2[j].synthflags & SFLAG_SWITCHED_LANG) {
-				stop_propagation = 0;
+				stop_propagation = false;
 				voicing = 0;
 				if (regression & 0x100)
 					voicing = 1; // word-end devoicing
@@ -208,7 +230,7 @@ void MakePhonemeList(Translator *tr, int post_pause, int start_sentence)
 			if (regression & 0x2) {
 				// [v] amd [v;] don't cause regression, or [R^]
 				if (((ph->mnemonic & 0xff) == 'v') || ((ph->mnemonic & 0xff) == 'R')) {
-					stop_propagation = 1;
+					stop_propagation = true;
 					if (regression & 0x10)
 						voicing = 0;
 				}
@@ -234,7 +256,7 @@ void MakePhonemeList(Translator *tr, int post_pause, int start_sentence)
 			}
 			if (stop_propagation) {
 				voicing = 0;
-				stop_propagation = 0;
+				stop_propagation = false;
 			}
 
 			if (plist2[j].sourceix) {
@@ -301,7 +323,7 @@ void MakePhonemeList(Translator *tr, int post_pause, int start_sentence)
 					k = word_start;
 					word_start--;
 				} else
-					k = 2;   // No more space, don't lose the start of word mark at ph_list2[word_start]
+					k = 2;   // No more space, don't loose the start of word mark at ph_list2[word_start]
 				for (; k <= j; k++)
 					memcpy(&ph_list3[k-1], &ph_list3[k], sizeof(*plist3));
 			}
@@ -339,7 +361,7 @@ void MakePhonemeList(Translator *tr, int post_pause, int start_sentence)
 		}
 
 		if (((alternative = phdata.pd_param[pd_INSERTPHONEME]) > 0) && (inserted == false)) {
-			// PROBLEM: if we insert a phoneme before a vowel then we lose the stress.
+			// PROBLEM: if we insert a phoneme before a vowel then we loose the stress.
 			PHONEME_TAB *ph2;
 			ph2 = ph;
 
@@ -495,11 +517,16 @@ void MakePhonemeList(Translator *tr, int post_pause, int start_sentence)
 
 			if (plist3->sourceix != 0) {
 				phlist[ix].sourceix = plist3->sourceix;
-				phlist[ix].newword = 1; // this phoneme is the start of a word
+				phlist[ix].newword = PHLIST_START_OF_WORD;
 
 				if (start_sentence) {
-					phlist[ix].newword = 5; // start of sentence + start of word
-					start_sentence = 0;
+					phlist[ix].newword |= PHLIST_START_OF_SENTENCE;
+					start_sentence = false;
+				}
+
+				if (start_of_clause) {
+					phlist[ix].newword |= PHLIST_START_OF_CLAUSE;
+					start_of_clause = false;
 				}
 			} else
 				phlist[ix].newword = 0;
@@ -522,7 +549,8 @@ void MakePhonemeList(Translator *tr, int post_pause, int start_sentence)
 			ix++;
 		}
 	}
-	phlist[ix].newword = 2; // end of clause
+
+	phlist[ix].newword = PHLIST_END_OF_CLAUSE;
 
 	phlist[ix].phcode = phonPAUSE;
 	phlist[ix].type = phPAUSE; // terminate with 2 Pause phonemes
