@@ -1,6 +1,6 @@
 /* Manipulation.cpp
  *
- * Copyright (C) 1992-2012,2014-2020 Paul Boersma
+ * Copyright (C) 1992-2012,2014-2022 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -575,7 +575,8 @@ static autoSound synthesize_pulses_pitch_hum (Manipulation me) {
 /*
 void Sound_Formant_Intensity_filter (Sound me, FormantTier formantTier, IntensityTier intensity) {
 	Sound_FormantTier_filter_inplace (me, formantTier);
-	if (intensity) Sound_IntensityTier_multiply_inplace (me, intensity);
+	if (intensity)
+		Sound_IntensityTier_multiply_inplace (me, intensity);
 	VECdeemphasize_f_inplace (my z.row (1), my dx, 50.0);
 	Vector_scale (me, 0.99);
 }
