@@ -1,6 +1,6 @@
 /* Sampled.cpp
  *
- * Copyright (C) 1992-2005,2007,2008,2011,2012,2014-2020 Paul Boersma
+ * Copyright (C) 1992-2005,2007,2008,2011,2012,2014-2021 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -174,8 +174,6 @@ autoVEC Sampled_getSortedValues (Sampled me, double xmin, double xmax, integer l
 double Sampled_getQuantile (Sampled me, double xmin, double xmax, double quantile, integer levelNumber, int unit) {
 	try {
 		autoVEC values = Sampled_getSortedValues (me, xmin, xmax, levelNumber, unit);
-		if (values.size == 0)
-			return undefined;
 		return NUMquantile (values.get(), quantile);
 	} catch (MelderError) {
 		Melder_throw (me, U": quantile not computed.");
@@ -183,7 +181,7 @@ double Sampled_getQuantile (Sampled me, double xmin, double xmax, double quantil
 }
 
 static void Sampled_getSumAndDefinitionRange
-	(Sampled me, double xmin, double xmax, integer levelNumber, int unit, bool interpolate, double *return_sum, double *return_definitionRange)
+	(Sampled me, double xmin, double xmax, integer levelNumber, int unit, bool interpolate, double *out_sum, double *out_definitionRange)
 {
 	/*
 		This function computes the area under the linearly interpolated curve between xmin and xmax.
@@ -317,8 +315,10 @@ static void Sampled_getSumAndDefinitionRange
 			}
 		}
 	}
-	if (return_sum) *return_sum = (double) sum;
-	if (return_definitionRange) *return_definitionRange = (double) definitionRange;
+	if (out_sum)
+		*out_sum = double (sum);
+	if (out_definitionRange)
+		*out_definitionRange = double (definitionRange);
 }
 
 double Sampled_getMean (Sampled me, double xmin, double xmax, integer levelNumber, int unit, bool interpolate) {
@@ -344,7 +344,7 @@ double Sampled_getIntegral_standardUnit (Sampled me, double xmin, double xmax, i
 }
 
 static void Sampled_getSum2AndDefinitionRange
-	(Sampled me, double xmin, double xmax, integer levelNumber, int unit, double mean, bool interpolate, double *return_sum2, double *return_definitionRange)
+	(Sampled me, double xmin, double xmax, integer levelNumber, int unit, double mean, bool interpolate, double *out_sum2, double *out_definitionRange)
 {
 	/*
 		This function computes the area under the linearly interpolated squared difference curve between xmin and xmax.
@@ -506,8 +506,10 @@ static void Sampled_getSum2AndDefinitionRange
 			}
 		}
 	}
-	if (return_sum2) *return_sum2 = (double) sum2;
-	if (return_definitionRange) *return_definitionRange = (double) definitionRange;
+	if (out_sum2)
+		*out_sum2 = double (sum2);
+	if (out_definitionRange)
+		*out_definitionRange = double (definitionRange);
 }
 
 double Sampled_getStandardDeviation (Sampled me, double xmin, double xmax, integer levelNumber, int unit, bool interpolate) {
@@ -574,9 +576,9 @@ void Sampled_getMinimumAndX (Sampled me, double xmin, double xmax, integer level
 						xOfMinimum = i;
 					}
 				} else if (fmid < fleft && fmid <= fright) {
-					double y [3] = { fleft, fmid, fright };
+					const double y [] = { fleft, fmid, fright };
 					double i_real;
-					const double localMinimum = NUMimproveMinimum (constVEC (y, 3), 2, NUM_PEAK_INTERPOLATE_PARABOLIC, & i_real);
+					const double localMinimum = NUMimproveMinimum (ARRAY_TO_VEC (y), 2, NUM_PEAK_INTERPOLATE_PARABOLIC, & i_real);
 					if (localMinimum < minimum) {
 						minimum = localMinimum;
 						xOfMinimum = i_real + i - 2;
@@ -675,9 +677,9 @@ void Sampled_getMaximumAndX (Sampled me, double xmin, double xmax, integer level
 						xOfMaximum = i;
 					}
 				} else if (fmid > fleft && fmid >= fright) {
-					double y [3] = { fleft, fmid, fright };
+					const double y [] = { fleft, fmid, fright };
 					double i_real;
-					const double localMaximum = NUMimproveMaximum (constVEC (y, 3), 2, NUM_PEAK_INTERPOLATE_PARABOLIC, & i_real);
+					const double localMaximum = NUMimproveMaximum (ARRAY_TO_VEC (y), 2, NUM_PEAK_INTERPOLATE_PARABOLIC, & i_real);
 					if (localMaximum > maximum) {
 						maximum = localMaximum;
 						xOfMaximum = i_real + i - 2;
@@ -769,10 +771,10 @@ void Sampled_drawInside (Sampled me, Graphics g, double xmin, double xmax, doubl
 		if (ymax <= ymin)
 			return;
 		Graphics_setWindow (g, xmin, xmax, ymin, ymax);
-		auto const lowIndex = ixmin - 1, highIndex = ixmax + 1;
-		auto const nbuffer = highIndex - lowIndex + 1;
-		auto xbuffer = zero_VEC (nbuffer), ybuffer = zero_VEC (nbuffer);
-		auto const bufferShift = 1 - lowIndex;
+		const integer lowIndex = ixmin - 1, highIndex = ixmax + 1;
+		const integer nbuffer = highIndex - lowIndex + 1;
+		autoVEC xbuffer = zero_VEC (nbuffer), ybuffer = zero_VEC (nbuffer);
+		const integer bufferShift = 1 - lowIndex;
 		double *xarray = & xbuffer [bufferShift];
 		double *yarray = & ybuffer [bufferShift];
 		double previousValue = Sampled_getValueAtSample (me, lowIndex, levelNumber, unit);
@@ -801,7 +803,7 @@ void Sampled_drawInside (Sampled me, Graphics g, double xmin, double xmax, doubl
 					xarray [ix] = x - 0.5 * my dx;
 					yarray [ix] = previousValue;
 					if (xarray [startOfDefinedStretch] < xmin) {
-						double phase = (xmin - xarray [startOfDefinedStretch]) / my dx;
+						const double phase = (xmin - xarray [startOfDefinedStretch]) / my dx;
 						xarray [startOfDefinedStretch] = xmin;
 						yarray [startOfDefinedStretch] = phase * yarray [startOfDefinedStretch + 1] + (1.0 - phase) * yarray [startOfDefinedStretch];
 					}
