@@ -1,6 +1,6 @@
 /* Spectrum.cpp
  *
- * Copyright (C) 1992-2008,2011,2012,2014-2022 Paul Boersma
+ * Copyright (C) 1992-2008,2011,2012,2014-2023 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -60,7 +60,7 @@ void structSpectrum :: v1_info () {
 	MelderInfo_writeLine (U"Total energy: ", Melder_single (Spectrum_getBandEnergy (this, 0.0, 0.0)), U" Pa2 sec");
 }
 
-double structSpectrum :: v_getValueAtSample (integer isamp, integer which, int units) {
+double structSpectrum :: v_getValueAtSample (integer isamp, integer which, int units) const {
 	if (units == 0) {
 		return which == 1 ? z [1] [isamp] : which == 2 ? z [2] [isamp] : undefined;
 	} else {
